@@ -62,6 +62,44 @@ SAUF
 */
 
 
+
+// FILE IS VIDM4A ?
+//
+gboolean FileIs_vidm4a( gchar *namefile )
+{
+	FILE        *fp = NULL;
+	size_t       lenread = 0;
+	gchar       *buf = NULL;
+	gint         cpt;
+	gboolean     bool_signature = FALSE;
+	
+	if( (buf = (gchar *)g_malloc0 (sizeof(gchar) * 2048)) == NULL ) return (FALSE);
+	if( (fp = fopen (namefile, "rb")) != NULL ) {
+		lenread = fread( buf, 1, 2000, fp );
+		fclose (fp);
+	}
+
+	for (cpt = 0; cpt < 2000; cpt ++ ) {
+		if( buf [ cpt +  0 ] == 0x6D &&		// m
+		    buf [ cpt +  1 ] == 0x6F &&		// o
+		    buf [ cpt +  2 ] == 0x6F &&		// o
+		    buf [ cpt +  3 ] == 0x76 &&		// v
+		    buf [ cpt +  4 ] == 0x00 &&		// \0
+		    buf [ cpt +  5 ] == 0x00 &&		// \0
+		    buf [ cpt +  6 ] == 0x00 &&		// \0
+		    buf [ cpt +  7 ] == 0x6C &&		// l
+		    buf [ cpt +  8 ] == 0x6D &&		// m
+		    buf [ cpt +  9 ] == 0x76 &&		// v
+		    buf [ cpt + 10 ] == 0x68 &&		// h
+		    buf [ cpt + 11 ] == 0x64 ) {	// d
+		    
+		    bool_signature = TRUE;
+		    break;
+		}
+	}
+	return( bool_signature );
+}
+
 // FILE IS M4A ?
 //
 gboolean FileIs_m4a( gchar *namefile )
