@@ -38,6 +38,7 @@
 
 // FILE_IS.C
 // 
+gboolean	FileIs_vidm4a( gchar *namefile );
 gboolean	FileIs_m4a( gchar *namefile );
 gboolean	FileIs_wavpack (gchar *namefile);
 gboolean	FileIs_wav (gchar *namefile);
@@ -58,11 +59,12 @@ gboolean	FileIs_image( gchar *PathNameFile );
 
 // LIB.C
 // 
+gchar		*libutils_dup_chomp( gchar *p_str );
+gchar		*libutils_chomp( gchar *p_str );
 gchar		*libutils_get_prefix (gchar *PathNameFile);
 gboolean	libutils_access_mode (gchar *PathNameFile);
 gboolean	libutils_test_file_exist (gchar *File);
 gboolean	libutils_test_dir_exist (gchar *File);
-gboolean	libutils_new_strcmp (gchar *p_src, gchar *p_dest);
 void		libutils_set_default_icone_to_win (GtkWidget *win);
 gboolean	libutils_find_file (gchar *p_find_file);
 gchar		*libutils_get_pathname_pixmaps (gchar *p_name_pixmap);
@@ -77,7 +79,8 @@ GdkPixbuf	*libutils_init_pixbufs (char *NameFilePixbuf);
 gchar		*libutils_get_pathname_with_new_ext (gchar *PathName, gchar *NewExt);
 gboolean	libutils_test_file_with_new_ext_exist (gchar *PathName, gchar *NewExt);
 gint		*libutils_get_tab_selected_line (GtkTreeSelection *AdrLine, GtkTreeModel *AdrTreeModel);
-gchar		*libutils_get_name_without_ext (gchar *namefile);
+gchar		*libutils_get_name_without_ext_with_amp( gchar *p_PathNameFile );
+gchar		*libutils_get_name_without_ext( gchar *p_PathNameFile );
 gchar		*libutils_create_temporary_rep (gchar *SrcTmp, gchar *NewRepTmp);
 gchar		*libutils_remove_temporary_rep (gchar *path_tmprep);
 
