@@ -22,11 +22,20 @@
  * 
  *  You should have received a copy of the GNU General Public License
  *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ *  ---
+ *
+ *  Code de lecture audio pour fichiers de type WAV reprit et retravaille
+ *  depuis:
+ *  	Analyse code depuis: wavbreaker
+ *  	par Timothy Robinson et Thomas Perl
+ *  	http://wavbreaker.sourceforge.net/
+ *
  */
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
