@@ -45,6 +45,7 @@ typedef enum {
 
 
 typedef struct {
+	GtkComboBox		*Adr_combobox_discid_cd;		// 
 	GtkComboBox		*Adr_combobox_normalise_cd;		// 
 	GtkComboBox		*Adr_Combo_Box;				// 
 	GtkComboBox		*Adr_combobox_serveur;			// 
@@ -243,7 +244,6 @@ typedef struct {							// UN ENTETE POUR LE CD
 	gchar			 Str_Bitrate_Lame [ 10 ];		// Bitrate pour Lame
 	gchar			 Str_Bitrate_oggenc [ 10 ]; 		// Bitrate pour Oggenc
 	gchar			*StrMemoTagComment;			// Memorisation du commentaire
-	gint			ForceValueGenre;			// 
 } ENTETE_CD;
 
 extern ENTETE_CD EnteteCD;
@@ -282,6 +282,7 @@ void		cdaudio_put_label_titre (gchar *Messag);
 void		cdaudio_put_label_duree (gchar *Messag);
 gchar		*cdaudio_get_TitleCD (void);
 void		cdaudio_from_popup (TYPE_SET_FROM_POPUP_CD TypeSetFromPopup, CD_AUDIO *Audio, TYPE_FILE_IS TypeFileIs);
+void		cd_audio_bool_access_discid( gboolean p_bool_access );
 
 /*
 *---------------------------------------------------------------------------
