@@ -78,6 +78,7 @@
 #include "notify_send.h"
 #include "win_scan.h"
 #include "popup_systray.h"
+#include "win_vte.h"
 #include "cd_audio_extract.h"
 
 
@@ -582,11 +583,11 @@ gchar *cdaudioextract_new_name (gchar *Name, gchar *New)
 }
 // 
 // 
-void cdaudioextract_set_list_textview (gchar *p_text)
+void cdaudioextract_set_list_to_vte (gchar *p_text)
 {
 	conv.ListPutTextview = g_list_append (conv.ListPutTextview, g_strdup (p_text));
 	conv.BoolPutTextview = TRUE;
-	g_print("\n****\n%s****\n", p_text);
+	// g_print("\n****\n%s****\n", p_text);
 }
 // 
 // 
@@ -655,14 +656,14 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtarct_1, gchar *FileExtarct_2
 					if (NbrPass <= 4) {
 						// Si le contenu des segments est different
 						Str = g_strdup_printf (_("[Erreur du segment numero: %d]\n%d) Lecture PASS 1/2\n"), Elem, NbrPass);
-						cdaudioextract_set_list_textview (Str);
+						cdaudioextract_set_list_to_vte (Str);
 						g_free (Str);
 						Str = NULL;
 						BoolDiff = TRUE;
 					}
 					else { // NbrPass > 4
 						Str = g_strdup_printf (_("--> Deja %d fois 2 lectures du segment %d!\n    Abandon  :/\n"), NbrPass, Elem);
-						cdaudioextract_set_list_textview (Str);
+						cdaudioextract_set_list_to_vte (Str);
 						g_free (Str);
 						Str = NULL;
 					}
@@ -683,7 +684,7 @@ void cdaudioextract_copy_src_to_dest (gchar *FileExtarct_1, gchar *FileExtarct_2
 			
 			// Extraction segment 'Elem' PASS 2/2
 			Str = g_strdup_printf (_("%d) Lecture PASS 2/2\n"), NbrPass);
-			cdaudioextract_set_list_textview (Str);
+			cdaudioextract_set_list_to_vte (Str);
 			g_free (Str);
 			Str = NULL;
 			Name2 = cdaudioextract_new_name (FileExtarct_2, "2.wav");
@@ -763,11 +764,11 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 						// logs_writeln_datas ("EXTRACT_WITH_CDPARANOIA_EXPERT: ");
 						
 						Str = g_strdup_printf (_("\n[Piste: %d]\n"), Audio->Num_Track);
-						cdaudioextract_set_list_textview (Str);
+						cdaudioextract_set_list_to_vte (Str);
 						g_free (Str);
 						Str = NULL;
 						Str = g_strdup (_("Extraction mode expert PASS 1/2\n"));
-						cdaudioextract_set_list_textview (Str);
+						cdaudioextract_set_list_to_vte (Str);
 						g_free (Str);
 						Str = NULL;
 						
@@ -777,7 +778,7 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 					
 					if (FALSE == conv.bool_stop) {
 						
-						cdaudioextract_set_list_textview (_("Extraction mode expert PASS 2/2\n"));
+						cdaudioextract_set_list_to_vte (_("Extraction mode expert PASS 2/2\n"));
 						
 						cdaudioextract_restitue_arg_to_extract (Audio, NUM_WAV_EXPERT_2);
 						conv_exec_extract (Audio->ListConv[ NUM_WAV_EXPERT_2 ].WithCommandLineUser, CDPARANOIA_CD_TO_WAV_EXPERT, "CDPARANOIA_CD_TO_WAV_EXPERT");
@@ -785,7 +786,7 @@ static void cdaudioextract_thread_extraction_from_cd (void *arg)
 					
 					if (FALSE == conv.bool_stop) {
 						
-						cdaudioextract_set_list_textview (_("Controle du contenu des fichiers extraits\n"));
+						cdaudioextract_set_list_to_vte (_("Controle du contenu des fichiers extraits\n"));
 						
 						cdaudioextract_copy_src_to_dest (
 								Audio->ExtractExpert.Name1,
@@ -1360,38 +1361,22 @@ static void cdaudioextract_thread_conversion_from_cd (void *arg)
 // 
 static gint cdaudioextract_timeout (gpointer data)
 {
-	if (TRUE == conv.BoolPutTextview) {
-		if (NULL != conv.Adr_textview) {
+	if (TRUE == conv.BoolPutTextview && TRUE == WinVte_is_ok()) {
 
-			GList		*List = NULL;
-			GtkTextBuffer	*Buf = NULL;
-			GtkTextIter      End;
-			gchar		*Ptr = NULL;
-			GtkAdjustment	*Adj = NULL;
+		GList		*List = NULL;
+		gchar		*Ptr = NULL;
 		
-			Buf = gtk_text_view_get_buffer (GTK_TEXT_VIEW (conv.Adr_textview));
-			gtk_text_buffer_get_end_iter (Buf, &End);
-			gtk_text_buffer_place_cursor (Buf, &End);
-	 		if (NULL != (List = g_list_first (conv.ListPutTextview))) {
-				
-				Adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (GTK_WIDGET (GLADE_GET_OBJECT("scrolledwindow_windscan"))));
-				
-				while (List) {
-					if (NULL != (Ptr = (gchar *)List->data)) {
-						gtk_text_buffer_insert_at_cursor (Buf, Ptr, -1);
-						g_free (Ptr);
-						Ptr = NULL;
-						List->data = NULL;
-						gtk_adjustment_set_value (Adj, Adj->upper + 50.0);
-						gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (GTK_WIDGET (GLADE_GET_OBJECT("scrolledwindow_windscan"))), Adj);
-					}
-					List = g_list_next(List);
+	 	if (NULL != (List = g_list_first (conv.ListPutTextview))) {
+			while (List) {
+				if (NULL != (Ptr = (gchar *)List->data)) {
+					WinVte_window_write_va( Ptr, NULL );
+					g_free (Ptr);
+					Ptr = NULL;
+					List->data = NULL;
 				}
-				conv.BoolPutTextview = FALSE;
-				
-				gtk_adjustment_set_value (Adj, Adj->upper + 50.0);
-				gtk_scrolled_window_set_vadjustment (GTK_SCROLLED_WINDOW (GTK_WIDGET (GLADE_GET_OBJECT("scrolledwindow_windscan"))), Adj);
+				List = g_list_next(List);
 			}
+			conv.BoolPutTextview = FALSE;
 		}
 	}
 
@@ -1431,6 +1416,8 @@ static gint cdaudioextract_timeout (gpointer data)
 	if (TRUE == conv.bool_percent_extract || TRUE == conv.bool_percent_conv) {
 		gchar	*Str = NULL;
 		
+		// DEBUG
+		if( conv.total_percent > 1.0 ) conv.total_percent = 1.0;
 		Str = g_strdup_printf ("%d%%", (int)(conv.total_percent * 100));
 		WindScan_set_progress (Str, conv.total_percent);
 		g_free (Str);
@@ -1957,7 +1944,8 @@ void cdaudioextract_extraction_cd_to_file_action (void)
 	WindScan_set_pulse ();
 	if (EXTRACT_WITH_CDPARANOIA_EXPERT == Config.ExtractCdWith) {
 		WindScan_show_expander ();
-		conv.Adr_textview = GTK_WIDGET (GLADE_GET_OBJECT("textview_windscan"));
+		// cwhile (gtk_events_pending()) gtk_main_iteration();
+		WinVte_reset();
 	}
  	conv.bool_thread_conv = TRUE;
 	VarCdExtract.NbrFileUnique = 0;
