@@ -106,7 +106,7 @@ void cdcue_remove_base_ioctl (void)
 		BaseIoctl.Datas = NULL;
 	}
 	
-	/*g_free (BaseIoctl.PathNameDestFileCue);	BaseIoctl.PathNameDestFileCue = NULL;*/
+	// g_free (BaseIoctl.PathNameDestFileCue);	BaseIoctl.PathNameDestFileCue = NULL;
 	g_free (BaseIoctl.Performer);		BaseIoctl.Performer = NULL;
 	g_free (BaseIoctl.Title);		BaseIoctl.Title = NULL;
 	g_free (BaseIoctl.File);		BaseIoctl.File = NULL;
@@ -135,7 +135,7 @@ void cdcue_alloc_base_ioctl (gint p_taille)
 	
 	BaseIoctl.Cue = (CDCUE *)g_malloc0 (sizeof(CDCUE) * (p_taille +4));
 	
-	/* Aucune extraction */
+	// Aucune extraction
 	for (index = 0; index < p_taille; index ++)
 		BaseIoctl.Cue [ index ].BoolExtract = FALSE;
 }
@@ -153,12 +153,11 @@ void cdcue_print_base_ioctl (void)
 	gint   TempDiv;
 	gint   TempMod;
 	
-	/*
-	1. length   12923 [02:52:23]  begin      32 [00:00:32]	cdparanoia [.begin<44 ? 0 : begin][.(length + begin) -1] -d /dev/hdb -O 0 "1.wav"
-	2. length   14175 [03:09:00]  begin   12955 [02:52:55]	cdparanoia [.begin][.length -1] -d /dev/hdb -O 0 "2.wav"
-	3. length   14627 [03:15:02]  begin   27130 [06:01:55]	cdparanoia [.begin][.length -1] -d /dev/hdb -O 0 "3.wav"
-	*/	
-	
+	// 1. length   12923 [02:52:23]  begin      32 [00:00:32]	cdparanoia [.begin<44 ? 0 : begin][.(length + begin) -1] -d /dev/hdb -O 0 "1.wav"
+	// 2. length   14175 [03:09:00]  begin   12955 [02:52:55]	cdparanoia [.begin][.length -1] -d /dev/hdb -O 0 "2.wav"
+	// 3. length   14627 [03:15:02]  begin   27130 [06:01:55]	cdparanoia [.begin][.length -1] -d /dev/hdb -O 0 "3.wav"
+	// 20. length   15848 [03:31:23]  begin  303192 [67:22:42]	cdparanoia [.303192]-[.15847] -d /dev/sr0 -O 0 "20.wav"
+	g_print("  ------------------ B A S E ----------------------------       ---------------- E X T R A C T I O N -----------------\n" );
 	for (base = 0; base < BaseIoctl.TotalTracks; base++) {
 		TempDiv = BaseIoctl.Datas[ base ].length / 75;
 		TempMod = BaseIoctl.Datas[ base ].length % 75;
@@ -189,8 +188,7 @@ void cdcue_print_base_ioctl (void)
 			EnteteCD.NameCD_Device,
 			base +1
 			);
-			
-			
+		
 		if (BaseIoctl.Cue [ base ].BoolExtract == TRUE)
 			g_print(" -> Extract");
 		
@@ -247,7 +245,8 @@ void cdcue_write_cue_ok (void)
 	
 	PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config.PathDestinationCD, BaseIoctl.Performer);
 	
-	PRINT("Production du fichier");
+	PRINT("Production du fichier:");
+	g_print("\t%s\n", PathName );
 
 	fp = fopen (PathName, "w");
 
@@ -263,13 +262,11 @@ void cdcue_write_cue_ok (void)
 		if (piste > 0)
 		fprintf (fp,   "    INDEX 00 %02d:%02d:%02d\n", BaseIoctl.Cue [ piste ].EndTime.min, BaseIoctl.Cue [ piste ].EndTime.sec, BaseIoctl.Cue [ piste ].EndTime.cent);
 		fprintf (fp,   "    INDEX 01 %02d:%02d:%02d\n", BaseIoctl.Cue [ piste ].BeginTime.min, BaseIoctl.Cue [ piste ].BeginTime.sec, BaseIoctl.Cue [ piste ].BeginTime.cent);
-/*
-g_print ("    PERFORMER \"%s\"\n", BaseIoctl.Cue [ piste ].Performer);
-g_print ("    TITLE \"%s\"\n", BaseIoctl.Cue [ piste ].Title);
-if (piste > 0)
-g_print ("    INDEX 00 %02d:%02d:%02d\n", BaseIoctl.Cue [ piste ].FMin, BaseIoctl.Cue [ piste ].FSec, BaseIoctl.Cue [ piste ].FCent);
-g_print ("    INDEX 01 %02d:%02d:%02d\n", BaseIoctl.Cue [ piste ].DMin, BaseIoctl.Cue [ piste ].DSec, BaseIoctl.Cue [ piste ].DCent);
-*/
+// g_print ("    PERFORMER \"%s\"\n", BaseIoctl.Cue [ piste ].Performer);
+// g_print ("    TITLE \"%s\"\n", BaseIoctl.Cue [ piste ].Title);
+// if (piste > 0)
+// g_print ("    INDEX 00 %02d:%02d:%02d\n", BaseIoctl.Cue [ piste ].FMin, BaseIoctl.Cue [ piste ].FSec, BaseIoctl.Cue [ piste ].FCent);
+// g_print ("    INDEX 01 %02d:%02d:%02d\n", BaseIoctl.Cue [ piste ].DMin, BaseIoctl.Cue [ piste ].DSec, BaseIoctl.Cue [ piste ].DCent);
 	}
 	fprintf (fp,   "\n");
 
@@ -277,14 +274,13 @@ g_print ("    INDEX 01 %02d:%02d:%02d\n", BaseIoctl.Cue [ piste ].DMin, BaseIoct
 	g_free (PathName);
 	PathName = NULL;
 		
-	/* FIN de creation CUE-FILE */
+	// FIN de creation CUE-FILE
 	var_cd.TypeCreateCue = TYPE_CUE_NONE;
 }
-/* ADD == 0 : no change
-   ADD == 1 : + 3 secondes
-   ADD == 2 : - 3 secondes
-*/
 // 
+// ADD == 0 : no change
+// ADD == 1 : + 3 secondes
+// ADD == 2 : - 3 secondes
 // 
 void cdcue_calcul_start (gint piste, gint Add)
 {
@@ -328,6 +324,8 @@ FILE "aurelie.wav" WAVE
     INDEX 00 05:00:00		FIN	Think
     INDEX 01 05:00:32		DEBUT	Nigth
 */
+// 
+// 
 void cdcue_write_cue_ok_partiel (void)
 {
 	gint	 piste;
@@ -337,10 +335,7 @@ void cdcue_write_cue_ok_partiel (void)
 	FILE	*fp;
 	gchar	*PathName = NULL;
 	
-	/*gint	 TempDiv;
-	gint	 TempMod;*/
-	
-	/* Initialisation */
+	// Initialisation
 	for (piste = 0; piste < BaseIoctl.TotalTracks; piste ++) {
 		BaseIoctl.Cue [ piste ].CuePartiel.Start     = 0;
 		BaseIoctl.Cue [ piste ].CuePartiel.StartMin  = 0;
@@ -350,15 +345,15 @@ void cdcue_write_cue_ok_partiel (void)
 		BaseIoctl.Cue [ piste ].CuePartiel.Len     = 0;
 	}
 	
-	/* init Len */
+	// init Len
 	for (piste = 0; piste < BaseIoctl.TotalTracks; piste ++) {
 		BaseIoctl.Cue [ piste ].CuePartiel.Len     = BaseIoctl.Datas[ piste ].length;
 	}
 	
-	/* Init Start ZERO */
+	// Init Start ZERO
 	BaseIoctl.Cue [ 0 ].CuePartiel.Start = BaseIoctl.Datas[ 0 ].begin;
 	
-	/* Init Start ZERO */
+	// Init Start ZERO
 	old_piste = 0;
 	for (piste = 0; piste < BaseIoctl.TotalTracks; piste ++) {
 		if (BaseIoctl.Cue [ piste ].BoolExtract == TRUE) {
@@ -387,10 +382,7 @@ void cdcue_write_cue_ok_partiel (void)
 	Ptr = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue));
 	PathName = g_strdup_printf ("%s/%s.cue", (gchar *)Config.PathDestinationCD, Ptr);
 	
-	/*fp = fopen (PathName, "w");*/
 	fp = fopen (BaseIoctl.PathNameDestFileCue, "w");
-	/*g_print ("PathName =  = %s\n", PathName);
-	g_print ("BaseIoctl.PathNameDestFileCue = %s\n", BaseIoctl.PathNameDestFileCue);*/
 	
 	g_print("\n");
 	fprintf (fp,   "REM Cue file written by Xcfa\n\n");
@@ -417,11 +409,6 @@ void cdcue_write_cue_ok_partiel (void)
 		fprintf (fp,   "    TITLE \"%s\"\n", BaseIoctl.Cue [ piste ].Title);
 		
 		if (track == 0) {
-			/*g_print("    %02d track == 0\n", piste);*/
-			/*g_print("    INDEX 01 %02d:%02d:%02d\n",
-				BaseIoctl.Cue [ 0 ].CuePartiel.StartMin,
-				BaseIoctl.Cue [ 0 ].CuePartiel.StartSec,
-				BaseIoctl.Cue [ 0 ].CuePartiel.StartCent);*/
 			fprintf (fp,   "    INDEX 01 00:00:00\n");
 			track ++;
 			old_piste = piste;
@@ -449,7 +436,7 @@ void cdcue_write_cue_ok_partiel (void)
 	g_free (PathName);
 	PathName = NULL;
 		
-	/* FIN de creation CUE-FILE */
+	// FIN de creation CUE-FILE
 	var_cd.TypeCreateCue = TYPE_CUE_NONE;
 }
 // 
@@ -468,7 +455,6 @@ void cdcue_write_cue (void)
 		
 	case TYPE_CUE_FILE :
 		if (gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_creation_fichier_cue"))) == TRUE) {
-			
 			/*
 			if (libutils_test_file_exist (BaseIoctl.PathNameDestFileCue) == TRUE) {
 				
@@ -506,7 +492,7 @@ void cdcue_write_cue (void)
 		break;
 	}
 	
-	/* FIN de creation CUE-FILE */
+	// FIN de creation CUE-FILE
 	var_cd.TypeCreateCue = TYPE_CUE_NONE;
 	
 	/*
@@ -527,10 +513,10 @@ static gint cdcue_timeout (gpointer data)
 {
 	if (var_cd.bool_timeout_read_toc_cd == FALSE) {
 		
-		/* Creation de fichier CUE */
+		// Creation de fichier CUE
 		cdcue_write_cue ();
 		
-		/* FIN timeout */
+		// FIN timeout
 		gtk_timeout_remove (cdcue.handler_timeout);
 	}
 	
@@ -543,24 +529,23 @@ void on_button_cue_creation_from_cd_clicked (GtkButton *button, gpointer user_da
 	
 	if (cdcue_is_alloc () == TRUE) {
 		
-		/* DEBUT de creation de fichier CUE */
+		// DEBUT de creation de fichier CUE
 		var_cd.TypeCreateCue = TYPE_CUE_CD;
 		
 		cdcue_write_cue ();
 	}
 	else {
-	
-		/* DEBUT de creation de fichier CUE */
+		// DEBUT de creation de fichier CUE
 		var_cd.TypeCreateCue = TYPE_CUE_CD;
 
-		/* Pré-initialisations indispensable */
+		// Pré-initialisations indispensable
 		var_cd.bool_thread_read_toc_cd = TRUE;
 		var_cd.bool_timeout_read_toc_cd = TRUE;
 		
-		/* Le timer de fin */
+		// Le timer de fin
 		cdcue.handler_timeout = gtk_timeout_add (100, cdcue_timeout, 0);
 		
-		/* Et action */
+		// Et action
 		cdaudiotoc_reffresh_list_cd ();
 	}
 }
@@ -582,7 +567,7 @@ void on_entry_name_fichier_unique_cue_changed (GtkEditable *editable, gpointer u
 
 	ptr_template = (gchar *)gtk_entry_get_text (GTK_ENTRY (var_cd.Adr_entry_name_file_cue));
 	
-	/* Suppression du caracteres '/' interdit si il existe */
+	// Suppression du caracteres '/' interdit si il existe
 	str = g_strdup (ptr_template);
 	if (strchr (str, '/')) {
 
