@@ -38,61 +38,47 @@ typedef struct {
 
 
 typedef struct {
-	/*
-	1. length   12375 [02:45:00]  begin      32 [00:00:32]
-
-	gint	Len;
-	gint	LenMin;
-	gint	LenSec;
-	gint	LenCent;
-	*/
-	gint	Len;
-  	gint	Start;
-	gint	StartMin;
-	gint	StartSec;
-	gint	StartCent;
+	// 1. length   12375 [02:45:00]  begin      32 [00:00:32]
+	gint	Len;							// 
+  	gint	Start;							// 
+	gint	StartMin;						// 
+	gint	StartSec;						// 
+	gint	StartCent;						// 
  } CDCUE_PARTIEL;
 	
 typedef struct {
-	gchar			*Performer;				/*  				*/
-	gchar			*Title;					/*  				*/
-	gboolean		 BoolExtract;				/* TRUE si extraction		*/
-	gchar			*Partiel_Title;				/*  				*/
-	
-	CUE_TIME		 EndTime;
-	CUE_TIME		 BeginTime;
-	
-	CDCUE_PARTIEL		 CuePartiel;
+	gchar			*Performer;				// 
+	gchar			*Title;					// 
+	gboolean		 BoolExtract;				// TRUE si extraction
+	gchar			*Partiel_Title;				// 
+	CUE_TIME		 EndTime;				// 
+	CUE_TIME		 BeginTime;				// 
+	CDCUE_PARTIEL		 CuePartiel;				// 
 } CDCUE;
 
-/*
-length DIV 75
-	DIV 60 = Min
-	MOD 60 = Sec
-	
-length MOD 75 = Cent
-*/
+// length DIV 75
+// 	DIV 60 = Min
+// 	MOD 60 = Sec
+// length MOD 75 = Cent
 typedef struct {
 	
-	gint			 length;				/* Longueur totale		*/
-	gint			 length_min ,length_sec ,length_cent;	/* Details			*/
-	gint			 begin;					/* Longueur totale		*/
-	gint			 begin_min ,begin_sec ,begin_cent;	/* Details			*/
+	gint			 length;				// Longueur totale
+	gint			 length_min ,length_sec ,length_cent;	// Details
+	gint			 begin;					// Longueur totale
+	gint			 begin_min ,begin_sec ,begin_cent;	// Details
 
 } BASE_IOCTL_DATAS;
 
 typedef struct {
-
-	/* Base obtenue pae IOCTL ou CDPARANOIA								*/
-	gint			 TotalTracks;				/* Nombre total de pistes	*/
-	BASE_IOCTL_DATAS	*Datas;					/*				*/
-	
-	/* CUE	*/
-	gchar			*Performer;				/*				*/
-	gchar			*Title;					/*				*/
-	gchar			*File;					/*				*/
-	CDCUE			*Cue;					/*				*/
-	gchar			*PathNameDestFileCue;			/*				*/
+	// Base obtenue pae IOCTL ou CDPARANOIA
+	gint			 TotalTracks;				// Nombre total de pistes
+	BASE_IOCTL_DATAS	*Datas;					//
+	// CUE
+	gchar			*Performer;				//
+	gchar			*Title;					//
+	gchar			*File;					//
+	CDCUE			*Cue;					//
+	gchar			*PathNameDestFileCue;			//
 	
 } BASE_IOCTL;
 
