@@ -56,36 +56,29 @@
 
 
 
-/*
 typedef struct {
-
-	gchar	*PathNameSrc;		// Le fichier a normaliser
-	gchar	*PathNameDest;		// Destination du fichier
-	AUDIO	*Audio;
-	
-} VAR_CD_NORMALISE_ELEMENT;
-
-typedef struct {
-	
-	GList	*ListPeakGroup;		// Pointeur sur AUDIO
-	gint	 MaxElements;		// 
-	gint	 NumExtract;		// 
-	gchar	*TmpRep;		// Le dossier temporaire
-	
+	GList	*ListPeakGroup;			// Pointeur sur AUDIO
+	gint	MaxElements;			// 
+	gint	NumExtract;			// 
+	gchar	*TmpRep;			// Le dossier temporaire
 } VAR_CD_NORMALISE;
-*/
-VAR_CD_NORMALISE VarCdNormalise = { NULL, 0, 0, NULL };
+
+VAR_CD_NORMALISE VarCdNormalise = {
+		NULL,				// GList	*ListPeakGroup
+		0,				// gint		MaxElements
+		0,				// gint		NumExtract
+		NULL				// gchar	*TmpRep
+		};
 
 
 
-/* PEAK GROUP
-*/
+// 
+// PEAK GROUP
+// 
 void CdNormalise_set_list_PeakGroup (CD_AUDIO *Audio)
 {
 	VAR_CD_NORMALISE_ELEMENT	*VarCDNormaliseElement = NULL;
 	
-	// PRINT_FUNC_LF();
-	
 	if (VarCdNormalise.TmpRep == NULL) {
 		VarCdNormalise.TmpRep = libutils_create_temporary_rep (Config.PathnameTMP, PATH_TMP_XCFA_CD_NORMALISE_PEAK_ALBUM );
 	}
