@@ -121,7 +121,7 @@ typedef struct {
 	gchar		*StringExpanderMac;		// 
 	gchar		*StringExpanderWavpack;		// 
 	
-	gint		 ServeurCddb;			// 
+	gint		 ServeurCddb;			// SERVER_CDDB_DEFAULT = 0 OR SERVER_CDDB_PARAM
 	gchar		*StringNameFile_m3u_xspf;	// 
 	gchar		*Templates_title_cdaudio;	// Format titres cdaudio
 	gchar		*Templates_rep_cdaudio;		// Dossier de sauvegarde des fichiers cdaudio
@@ -139,6 +139,8 @@ typedef struct {
 	gint		 NumSelectComboBoxCd;		// 
 	
 	gchar		*entry_cddp_server;		// 
+	gchar		*entry_proxy_server;		// 
+	gchar		*entry_proxy_port;		// 
 	
 	gchar		*NameImg;			// NEW
 	gchar		*PathLoadImg;			// 
