@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -56,6 +56,17 @@ GdkCursorType     cursor_type = GDK_LEFT_PTR;
 
 
 
+// 
+// 
+void cursor_set_clear (void)
+{
+	if (cursor_type != GDK_HAND2) {
+		cursor_type = GDK_HAND2;
+		_cursor = gdk_cursor_new (cursor_type);
+		gdk_window_set_cursor (GDK_WINDOW(WindMain->window), _cursor);
+		gdk_flush ();
+	}
+}
 // 
 // 
 void cursor_set_hand (void)
