@@ -26,7 +26,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -409,9 +409,9 @@ static gint dvdextract_timeout (gpointer data)
 		dvd_set_flag_buttons_dvd ();
 		
 		if (FALSE == conv.bool_stop) {
-			NotifySend_msg (_("XCFA: Extraction DVD"), _("Ok"));
+			NotifySend_msg (_("XCFA: Extraction DVD"), _("Ok"), conv.bool_stop);
 		} else {
-			NotifySend_msg (_("XCFA: Extraction DVD"), _("Arret par l'utilisateur"));
+			NotifySend_msg (_("XCFA: Extraction DVD"), _("Arret par l'utilisateur"), conv.bool_stop);
 		}
 	}
 	else if (TRUE == VarDvdextract.bool_mess) {
