@@ -44,15 +44,11 @@ typedef struct {
 	gchar			*Description;				// 
 } TAGS;
 
-/*
-*---------------------------------------------------------------------------
-* I N F O _
-*---------------------------------------------------------------------------
-*/
-
-typedef struct {
-	guint			 SecTime;				// 
-} VALUE_MARK;
+// 
+// ---------------------------------------------------------------------------
+//  I N F O _
+// ---------------------------------------------------------------------------
+// 
 
 typedef struct {
 	gint			 level;					// Niveau en dBFS
@@ -62,7 +58,6 @@ typedef struct {
 typedef struct {
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	VALUE_MARK		 ValueMark;				// 
 	gchar			*hertz;					// 
 	TAGS			*tags;					// Tags
 } INFO_M4A;
@@ -70,7 +65,6 @@ typedef struct {
 typedef struct {
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	VALUE_MARK		 ValueMark;				// 
 	gchar			*hertz;					// 
 	TAGS			*tags;					// Tags
 } INFO_AAC;
@@ -78,7 +72,6 @@ typedef struct {
 typedef struct {
 	gchar			*time;					//  Temps d'ecoute
 	guint			 SecTime;				//  Temps d'ecoute en secondes
-	VALUE_MARK		 ValueMark;				//  
 	gchar			*hertz;					// Taux d'échantillonnage en hertz( qualité du son)
 	gchar			*voie;					// 1, 2, 4, 6
 	gchar			*bits;					// 8, 16, ,24, 32 ou 64
@@ -101,7 +94,6 @@ typedef struct {
 	gchar			*bitrate;				// 
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	VALUE_MARK		 ValueMark;				// 
 	MPEG_IS			 mpeg_is;				// 
 	gchar			*size;					// 
 	TAGS			*tags;					// Tags
@@ -114,7 +106,6 @@ typedef struct {
 	gchar			*Nominal_bitrate;			// 
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	VALUE_MARK		 ValueMark;				// 
 	gchar			*size;					// 
 	TAGS			*tags;					// Tags
 	LEVEL_DBFS		 LevelDbfs;				// Datas du dBFS
@@ -123,7 +114,6 @@ typedef struct {
 typedef struct {
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	VALUE_MARK		 ValueMark;				// 
 	TAGS			*tags;					// Tags
 } INFO_FLAC;
 
@@ -152,7 +142,6 @@ typedef struct {
 	TAGS			*tags;					// Tags
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	VALUE_MARK		 ValueMark;				// 
 	gchar			*size;					// 
 } INFO_SHN;
 
@@ -160,7 +149,6 @@ typedef struct {
 	TAGS			*tags;					// Tags
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	VALUE_MARK		 ValueMark;				// 
 	gchar			*size;					// 
 } INFO_APE;
 
@@ -168,7 +156,6 @@ typedef struct {
 	TAGS			*tags;					// Tags
 	gchar			*time;					// Temps d'ecoute
 	guint			 SecTime;				// Temps d'ecoute en secondes
-	VALUE_MARK		 ValueMark;				// 
 	gchar			*size;					// 
 } INFO_WAVPACK;
 
@@ -176,11 +163,11 @@ typedef struct {
 	TAGS			*tags;					// Tags
 } INFO_AC3;
 
-/*
-*---------------------------------------------------------------------------
-* F I C    M P 3 O G G
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  F I C    M P 3 O G G
+// ---------------------------------------------------------------------------
+// 
 
 typedef struct {
 	gint			type;					// 
@@ -202,11 +189,11 @@ typedef struct {
 	TYPE_MP3OGG		Oggenc;					// 
 } CONV_FIC_MP3OGG;
 
-/*
-*---------------------------------------------------------------------------
-* F I C    W A V
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  F I C    W A V
+// ---------------------------------------------------------------------------
+// 
 
 typedef struct {
 	gchar			*Path;					// Path du fichier source
@@ -216,11 +203,11 @@ typedef struct {
 	gchar			*NameDest;				// Copie vers la destination
 } CONV_FIC_WAV;
 
-/*
-*---------------------------------------------------------------------------
-* F I C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  F I C
+// ---------------------------------------------------------------------------
+// 
 
 typedef enum {
 	FILE_IS_NONE = 0,
@@ -234,6 +221,7 @@ typedef enum {
 	   	.m4p( pour MPEG-4 Protégé),
 	   sont globalement plus petits que les fichiers au format MP3. */
 	FILE_IS_M4A,
+	FILE_IS_VID_M4A,
 	FILE_IS_AAC,
 	FILE_IS_SHN,
 	FILE_IS_WMA,
@@ -397,11 +385,11 @@ typedef enum {
 } TYPE_REMOVE_STRUCT;
 
 
-/*
-*---------------------------------------------------------------------------
-* F I C 
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  F I C 
+// ---------------------------------------------------------------------------
+// 
 
 
 typedef struct {
@@ -433,11 +421,11 @@ typedef struct {
 
 extern GList *entetefile;						// pointeur sur DETAIL
 
-/*
-*---------------------------------------------------------------------------
-* FILE.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE.C
+// ---------------------------------------------------------------------------
+// 
 typedef struct {
 	GtkComboBox		*AdrComboboxNormalise;			// Adresse
 	GtkSpinButton		*AdrSpinbuttonNormalise;		// Adresse
@@ -596,6 +584,11 @@ typedef enum {
 	FILEWAV_QUANTIFICATION_COL
 } TYPE_SET_FROM_POPUP_FILE;
 
+// 
+// ---------------------------------------------------------------------------
+//  FILE.C
+// ---------------------------------------------------------------------------
+// 
 gchar		*file_get_time( DETAIL *detail );
 void		file_scrolledwindow_file_realize( GtkWidget *widget );
 void		file_set_flag_buttons( void );
@@ -612,85 +605,73 @@ gchar		*file_get_pathname_dest( DETAIL *detail, gchar *NewExt );
 gchar		*file_get_size( DETAIL *detail );
 void		on_file_button_del_file_clicked( GtkButton *button, gpointer user_data );
 void		file_from_popup( TYPE_SET_FROM_POPUP_FILE TypeSetFromPopup, DETAIL *detail, TYPE_FILE_IS TypeFileIs );
-
-/*
-*---------------------------------------------------------------------------
-* FILE_SCAN_DB.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_SCAN_DB.C
+// ---------------------------------------------------------------------------
+// 
 void		FileScanDB_action( gboolean BoolAllScan );
-
-/*
-*---------------------------------------------------------------------------
-* FILE_ANALYZE.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_ANALYZE.C
+// ---------------------------------------------------------------------------
+// 
 #include "fileselect.h"
 
 void		fileanalyze_remove_entetefile( void );
 void		fileanalyze_add_file_to_treeview( TYPE_FILESELECTION p_TypeFileselection, GSList *p_list );
 gboolean	fileanalyze_exist( DETAIL *detail, gchar *NewExt );
-
-
-/*
-*---------------------------------------------------------------------------
-* FILE_CONV.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_CONV.C
+// ---------------------------------------------------------------------------
+// 
 void		fileconv_action( void );
-
-/*
-*---------------------------------------------------------------------------
-* FILE_MP3OGG.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_MP3OGG.C
+// ---------------------------------------------------------------------------
+// 
 void		FileMp3Ogg_set_flag_buttons( void );
 void		FileMp3Ogg_affiche_glist( void );
 gboolean	FileMp3Ogg_del_file_clicked( void );
 void		FileMp3Ogg_change_parameters( void );
-
-
-/*
-*---------------------------------------------------------------------------
-* FILE_MP3OGG_CONV.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_MP3OGG_CONV.C
+// ---------------------------------------------------------------------------
+// 
 void		filemp3oggconv_apply_regul_mp3ogg_by_conv( void );
-
-
-/*
-*---------------------------------------------------------------------------
-* FILE_WAV.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_WAV.C
+// ---------------------------------------------------------------------------
+// 
 void		FileWav_affiche_glist( void );
 void		FileWav_change_parameters( void );
 void		FileWav_set_flag_buttons( void );
 void		FileWav_from_popup( TYPE_SET_FROM_POPUP_FILE TypeSetFromPopup, DETAIL *detail, gint freq, gint voie, gint bits );
-
-/*
-*---------------------------------------------------------------------------
-* FILE_TAGS.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_TAGS.C
+// ---------------------------------------------------------------------------
+// 
 void		FileTags_affiche_glist( void );
 gboolean	FileWav_del_file_clicked( void );
 gboolean	FileTags_del_file_clicked( void );
 void		FileTags_appliquer_clicked( void );
 void		FileTags_set_flag_buttons( void );
-
-/*
-*---------------------------------------------------------------------------
-* FILE_WAV_CONV.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_WAV_CONV.C
+// ---------------------------------------------------------------------------
+// 
 void		filewavconv_apply( void );
-
-/*
-*---------------------------------------------------------------------------
-* FILE_ACTION.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_ACTION.C
+// ---------------------------------------------------------------------------
+// 
 typedef enum {
 	TYPE_REPLAYGAINCLEAR = 0,
 	TYPE_NORMALISE,
@@ -701,12 +682,11 @@ typedef enum {
 
 void		fileaction_choice( void );
 void		fileaction_set_end( FILEACTION_TYPE FileActionType );
-
-/*
-*---------------------------------------------------------------------------
-* FILE_LC.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_LC.C
+// ---------------------------------------------------------------------------
+// 
 #include "conv.h"
 
 typedef struct {
@@ -727,13 +707,11 @@ void		filelc_get_command_line( PARAM_FILELC *param_filelc );
 void		filelc_get_command_line_extract( PARAM_FILELC *param_filelc );
 GList		*filelc_remove_glist( GList *New );
 void		filelc_get_command_line_extract_elem( gint Elem, gchar *Dev, gchar *Dest );
-
-
-/*
-*---------------------------------------------------------------------------
-* FILE_TRASH.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  FILE_TRASH.C
+// ---------------------------------------------------------------------------
+// 
 void		filetrash_action( void );
 gboolean	filetrash_ok( void );
 gboolean	filetrash_move_to_trash( gchar *Name );
