@@ -56,7 +56,7 @@
 
 
 #ifdef HAVE_CONFIG_H
-	#include <config.h>
+	#include "../config.h"
 #endif
 
 #ifdef ENABLE_NLS
@@ -81,6 +81,7 @@
 #include "win_scan.h"
 #include "normalise.h"
 #include "popup_systray.h"
+#include "notify_send.h"
 
 
 /*
@@ -184,6 +185,12 @@ static gint fileaction_timeout (gpointer data)
 		PopupSystray_set_BoolMainAction (FALSE);
 		WindScan_close ();
 		gtk_timeout_remove (FileAction.handler_timeout);
+		
+		if (FALSE == conv.bool_stop) {
+			NotifySend_msg (_("XCFA: Traitement fichiers"), _("Ok"), conv.bool_stop);
+		} else {
+			NotifySend_msg (_("XCFA: Traitement fichiers"), _("Arret par l'utilisateur"), conv.bool_stop);
+		}
 	}
 	
 	return (TRUE);
@@ -218,6 +225,8 @@ void fileaction_choice (void)
 	FileAction.NbrFileRemove = 0;
 	conv.bool_stop = FALSE;
 	
+	// PRINT_FUNC_LF();
+	
 	// VERIFICATION DE LA PRESENCE DES FICHIERS SUR LA MEMOIRE DE MASSE
 	file_verify_before_conversion ();
 		
@@ -226,12 +235,7 @@ void fileaction_choice (void)
 	FileAction.bool_conversion         = file_get_bool_is_conversion ();
 	FileAction.bool_ReplaygainApply    = file_get_bool_ReplaygainApply ();
 	FileAction.bool_trash              = filetrash_ok ();
-	
-	// g_print("FileAction.bool_ReplaygainClear    = %s\n", FileAction.bool_ReplaygainClear ? "TRUE" : "FALSE");
-	// g_print("FileAction.bool_normalize          = %s\n", FileAction.bool_normalize ? "TRUE" : "FALSE");
-	// g_print("FileAction.bool_conversion         = %s\n", FileAction.bool_conversion ? "TRUE" : "FALSE");
-	// g_print("FileAction.bool_ReplaygainApply    = %s\n", FileAction.bool_ReplaygainApply ? "TRUE" : "FALSE");
-	
+		
 	PopupSystray_set_BoolMainAction (TRUE);
 	
 	FileAction.handler_timeout = gtk_timeout_add (150, fileaction_timeout, 0);
