@@ -128,10 +128,14 @@ void fileanalyze_remove_entetefile (void)
 	while (list) {
 		if (NULL != (detail = (DETAIL *)list->data)) {
 			
-			g_free (detail->namefile);
-			detail->namefile = NULL;
-			g_free (detail->NameDest);
-			detail->NameDest = NULL;
+			if( NULL != detail->namefile ) {
+				g_free( detail->namefile );
+				detail->namefile = NULL;
+			}
+			if( NULL != detail->NameDest ) {
+				g_free( detail->NameDest );
+				detail->NameDest = NULL;
+			}
 				
 			if (detail->type_infosong_file_is == FILE_IS_FLAC) {
 				INFO_FLAC *info = (INFO_FLAC *)detail->info;
@@ -156,6 +160,10 @@ void fileanalyze_remove_entetefile (void)
 				INFO_M4A *info = (INFO_M4A *)detail->info;
 				detail->info = (INFO_M4A *)tagsm4a_remove_info (info);
 			}
+			else if (detail->type_infosong_file_is == FILE_IS_VID_M4A) {
+				INFO_M4A *info = (INFO_M4A *)detail->info;
+				detail->info = (INFO_M4A *)tagsm4a_remove_info (info);
+			}
 			else if (detail->type_infosong_file_is == FILE_IS_AAC) {
 				INFO_AAC *info = (INFO_AAC *)detail->info;
 				detail->info = (INFO_AAC *)tagsaac_remove_info (info);
@@ -288,6 +296,7 @@ TYPE_FILE_IS fileanalyze_is_valid (gchar *PathName, TYPE_FILESELECTION p_TypeFil
 					FILE_IS_MP3,
 					FILE_IS_OGG,
 					FILE_IS_M4A,
+					FILE_IS_VID_M4A,
 					// FILE_IS_AAC,
 					FILE_IS_SHN,
 					FILE_IS_WMA,
@@ -467,7 +476,8 @@ void fileanalyze_set_in_list (void)
 			detail = (DETAIL *)g_malloc0 (sizeof (DETAIL));
 			detail->namefile              = g_strdup (VarListFiles->Name);
 			detail->NameFileCopyFromNormalizate = NULL;
-			detail->NameDest              = libutils_get_name_without_ext (VarListFiles->Name);
+			detail->NameDest              = libutils_get_name_without_ext( VarListFiles->Name );
+			
 			detail->type_infosong_file_is = VarListFiles->TypeFileIs;
 			
 			detail->EtatTrash             = FILE_TRASH_NONE;
@@ -522,6 +532,7 @@ void fileanalyze_set_in_list (void)
 			else if (VarListFiles->TypeFileIs == FILE_IS_DTS)     detail->info = tagsdts_get_info (detail);
 			else if (VarListFiles->TypeFileIs == FILE_IS_AIFF)    detail->info = tagsaiff_get_info (detail);
 			else if (VarListFiles->TypeFileIs == FILE_IS_M4A)     detail->info = tagsm4a_get_info (detail);
+			else if (VarListFiles->TypeFileIs == FILE_IS_VID_M4A) detail->info = tagsm4a_get_info (detail);
 			else if (VarListFiles->TypeFileIs == FILE_IS_MPC)     detail->info = tagsmpc_get_info (detail);
 			else if (VarListFiles->TypeFileIs == FILE_IS_APE)     detail->info = tagsape_get_info (detail);
 			else if (VarListFiles->TypeFileIs == FILE_IS_WAVPACK) detail->info = tagswavpack_get_info (detail);
