@@ -207,7 +207,8 @@ TAGS *FileTags_get_tag (DETAIL *detail)
 
 	case FILE_IS_AIFF :
 		infoAIFF = (INFO_AIFF *)detail->info;
-		tags = (TAGS  *)infoDTS->tags;
+		// tags = (TAGS  *)infoDTS->tags;
+		tags = (TAGS  *)infoAIFF->tags;
 		break;
 	
 	case FILE_IS_APE :
@@ -219,6 +220,10 @@ TAGS *FileTags_get_tag (DETAIL *detail)
 		infoM4A = (INFO_M4A *)detail->info;
 		tags = (TAGS  *)infoM4A->tags;
 		break;
+	case FILE_IS_VID_M4A :
+		infoM4A = (INFO_M4A *)detail->info;
+		tags = (TAGS  *)infoM4A->tags;
+		break;
 		
 	case FILE_IS_AAC :
 		infoAAC = (INFO_AAC *)detail->info;
@@ -900,7 +905,7 @@ void FileTags_affiche_glist (void)
 				continue;
 			}
 			
-			NameDest = libutils_get_name_without_ext (detail->namefile);
+			NameDest = libutils_get_name_without_ext_with_amp (detail->namefile);
 			
 			gtk_list_store_append (var_file_tags.Adr_List_Store, &iter);
 			gtk_list_store_set (var_file_tags.Adr_List_Store, &iter,
