@@ -281,7 +281,7 @@ void FileWav_affiche_glist (void)
 			NewVoie  = g_strdup_printf ("<span color=\"forestgreen\"><b>%s</b></span>", info->NewVoie);
 			NewBits  = g_strdup_printf ("<span color=\"forestgreen\"><b>%s</b></span>", info->NewBits);
 			
-			NameDest = libutils_get_name_without_ext (detail->namefile);
+			NameDest = libutils_get_name_without_ext_with_amp (detail->namefile);
 			
 			gtk_list_store_append (var_file_wav.Adr_List_Store, &iter);
 			gtk_list_store_set (var_file_wav.Adr_List_Store, &iter,
