@@ -802,7 +802,7 @@ void GetInfo_eject (gchar *StrDevice)
 }
 // 
 // 
-GString *GetInfo_cdparanoia (gchar *file)
+GString *GetInfo_cdparanoia( gchar *p_device )
 {
 	gint     fd;
 	gint     pos = 0;
@@ -814,17 +814,15 @@ GString *GetInfo_cdparanoia (gchar *file)
 	args[pos++] = "cdparanoia";
 	args[pos++] = "-Q";
 	args[pos++] = "-d";
-	args[pos++] = file;
+	args[pos++] = p_device;
 	args[pos++] = NULL;
 
-	/*
 	g_print ("!-----------------------------------!\n");
 	g_print ("!       C D P A R A N O I A         !\n");
 	g_print ("!-----------------------------------!\n");
 	for (pos = 0; args[ pos ] != NULL; pos++)
 		g_print ("args [ %02d ] = '%s'\n", pos, args [ pos ]);
 	g_print ("\n");
-	*/
 
 	fd = GetInfo_exec_with_output (args, &VarGet.code_fork, STDERR_FILENO);
 	do {
@@ -946,10 +944,16 @@ gboolean GetInfo_wget (void)
 		}
 		
 	} while (size != 0);
-
-	close(fd);
-	g_unlink ("/tmp/index.html");
 	
+	close(fd);
+	
+	if( TRUE == libutils_test_file_exist( "/tmp/index.html" )) {
+		g_unlink ("/tmp/index.html");
+		bool_access_ok = TRUE;
+	}
+	else {
+		bool_access_ok = FALSE;
+	}
 	return (bool_access_ok);
 }
 // 
@@ -967,6 +971,59 @@ SHNTAG *GetInfo_free_shntool (SHNTAG *ShnTag)
 	return ((SHNTAG *)NULL);
 
 }
+
+gchar *GetInfo_cd_discid( gchar *p_device )
+{
+	gint     fd;
+	gint     pos = 0;
+	gchar   *args [ 10 ];
+	gchar    buf [ GET_MAX_CARS + 10 ];
+	gint     size = 0;
+	GString *gstr = g_string_new (NULL);
+	gchar	*StrCdDiscId = NULL;
+
+	args[pos++] = "cd-discid";
+	args[pos++] = p_device;
+	args[pos++] = NULL;
+
+	
+	g_print( "\n" );
+	g_print ("!-----------------------------------!\n");
+	g_print ("!        C D - D I S C I D          !\n");
+	g_print ("!-----------------------------------!\n");
+	for( pos = 0; args[ pos ] != NULL; pos++ )
+		g_print( "args [ %02d ] = '%s'\n", pos, args [ pos ] );
+	g_print( "\n" );
+	
+	fd = GetInfo_exec_with_output( args, &VarGet.code_fork, STDOUT_FILENO );
+	do {
+		pos = -1;
+		do {
+			pos++;
+			if( pos >= GET_MAX_CARS ) {
+				PRINT_FUNC_LF();
+				g_print( "pos(%d) >= GET_MAX_CARS(%d)\n", pos, GET_MAX_CARS );
+				pos --;
+			}
+			size = read( fd, &buf[pos], 1 );
+
+		} while(( buf[pos] != '\b' ) && ( buf[pos] != '\r' ) && ( buf[pos] != '\n' ) && ( size > 0 ));
+		if( pos > 0 ) {
+			buf[pos ++ ] = '\n';
+			buf[pos] = '\0';
+			g_string_append_printf( gstr, "%s", buf );
+		}
+	} while( size != 0 );
+	close( fd );
+	
+	if( '\0' != *gstr->str )
+		StrCdDiscId = g_strdup( gstr->str );
+	g_string_free( gstr, TRUE );
+	gstr = NULL;
+		
+	return( StrCdDiscId );
+}
+
 SHNTAG *GetInfo_shntool (gchar *file)
 {
 	gint     fd;
@@ -1053,6 +1110,7 @@ SHNTAG *GetInfo_shntool (gchar *file)
 // 
 // RECONNAISSANCE ENTETE FICHIER:
 // 	FILE_IS_M4A
+// 	FILE_IS_VID_M4A
 // 	FILE_IS_WAVPACK
 // 	FILE_IS_WAVPACK_MD5
 // 	FILE_IS_WAV
@@ -1075,7 +1133,6 @@ TYPE_FILE_IS GetInfo_file_is( gchar *PathName )
 	GString		*gstr = NULL;
 	TYPE_FILE_IS	TypeFileRet = FILE_IS_NONE;
 	
-	
 	gstr = GetInfo_file (PathName);
 	// g_print( "gstr =\n%s\n", gstr->str );
 	// ABANDON SI LA COMMANDE file NE TROUVE PAS LE TYPE DE FICHIER
@@ -1086,21 +1143,41 @@ TYPE_FILE_IS GetInfo_file_is( gchar *PathName )
 	// UNE PETITE CHANCE SE PRESENTE ICI POUR AAC
 	else {
 		// FILE_IS_AAC
-		if( strstr (gstr->str, "AAC" ) || strstr (gstr->str, "MPEG ADTS, AAC," )) {
+		if( TRUE == FileIs_vidm4a( PathName )) {
+			TypeFileRet = FILE_IS_VID_M4A;
+		}
+		else if( strstr (gstr->str, "AAC" ) || strstr (gstr->str, "MPEG ADTS, AAC," )) {
 			TypeFileRet = FILE_IS_AAC;
 		}
 		// FILE_IS_WMA
 		else if (strstr (gstr->str, "Microsoft ASF")) {
 			TypeFileRet = FILE_IS_WMA;
 		}
-	
+		// FILE_IS_VID_M4A
+		// WCC_RADIO_EP042.m4a:			ISO Media, MPEG v4 system, iTunes AAC-LC
+		// 
+		// FILE_IS_M4A
+		// 21 The Academy.m4a:			ISO Media, MPEG v4 system, version 2
+		// 4 Non Blondes - Whats Going On.m4a:	ISO Media, MPEG v4 system, version 2
+		// audio.m4a:				ISO Media, MPEG v4 system, version 2
+		// 
+		// FILE_IS_AAC
+		// 01_King_Porter_Stomp.aac:		MPEG ADTS, AAC, v4 LC, 22.05 kHz, stereo
+		// aif.aac:				MPEG ADTS, AAC, v4 LC, 22.05 kHz, stereo
+		// audio.aac:				MPEG ADTS, AAC, v2 LC, 48 kHz, stereo
+	}
+	if( FILE_IS_VID_M4A == TypeFileRet || FILE_IS_AAC == TypeFileRet || FILE_IS_WMA == TypeFileRet ) {
+		g_string_free (gstr, TRUE);
+		gstr = NULL;
+		return( TypeFileRet );
+	}
+
+	// FILE_IS_VID_M4A
+	if( TRUE == FileIs_vidm4a( PathName )) {
+		TypeFileRet = FILE_IS_VID_M4A;
 	}
-	g_string_free (gstr, TRUE);
-	gstr = NULL;
-	if( FILE_IS_AAC == TypeFileRet || FILE_IS_WMA == TypeFileRet ) return( TypeFileRet );
-	
 	// FILE_IS_M4A
-	if( TRUE == FileIs_m4a( PathName )) {
+	else if( TRUE == FileIs_m4a( PathName )) {
 		TypeFileRet = FILE_IS_M4A;
 	}
 	// FILE_IS_WAVPACK
@@ -1152,6 +1229,14 @@ TYPE_FILE_IS GetInfo_file_is( gchar *PathName )
 	else if( TRUE == FileIs_mp3( PathName )) {
 		TypeFileRet = FILE_IS_MP3;
 	}
+	// FILE_IS_MP3
+	// Without tag id3 :/
+	else if( strstr (gstr->str, "MPEG ADTS, layer III" )) {
+		TypeFileRet = FILE_IS_MP3;
+	}
+	
+	g_string_free (gstr, TRUE);
+	gstr = NULL;
 	
 	return( TypeFileRet );
 }
