@@ -69,6 +69,7 @@
 #include "win_info.h"
 #include "popup_systray.h"
 #include "statusbar.h"
+#include "cd_curl.h"
 #include "global.h"
 
 // FIXME
@@ -159,7 +160,10 @@ void remove_memory_apply (void)
 
 	g_print ("web_remove_temporary_rep ()\n");
 	web_remove_temporary_rep ();
-
+	
+	g_print ("CdCurl_remove_struct_all ()\n");
+	CdCurl_remove_struct_all();
+	
 	g_print ("mplayer_remove_list_args ()\n");
 	mplayer_remove_list_args ();
 	
@@ -278,7 +282,7 @@ gboolean on_wind_main_key_press_event( GtkWidget *widget, GdkEventKey *kevent, g
 	}
 	
 	if( NOTEBOOK_POCHETTE == Config.NotebookGeneral ) {
-		if( kevent->keyval == GDK_Control_L || kevent->keyval == GDK_Control_R ) {
+		if( TRUE == keys.BoolGDK_Control_L_R ) {
 			pochedir_set_ctrl( TRUE );
 		}
 		else if( kevent->keyval == GDK_Delete) {
@@ -608,6 +612,8 @@ gint main (gint argc, gchar *argv[], gchar **envp)
 	gtk_widget_set_sensitive (GTK_WIDGET (var_file_tags.Adr_table_tag), FALSE);
 	gtk_widget_set_sensitive (GTK_WIDGET (GLADE_GET_OBJECT("button_tag_appliquer")), FALSE);
 	
+	gtk_widget_hide( GTK_WIDGET (GLADE_GET_OBJECT("frame_discid")));
+	
 	treeview_set_etat_fields ();
 	treeview_radiobutton_set_PosFieldsName ();
 	
