@@ -30,37 +30,19 @@
 
 typedef enum {
 	LIST_MPLAYER_FROM_NONE = 0,
-	LIST_MPLAYER_FROM_FILE,
 	LIST_MPLAYER_FROM_DVD,
-	LIST_MPLAYER_FROM_CD,
-	LIST_MPLAYER_FROM_SPLIT
-
+	LIST_MPLAYER_FROM_CD
 } LIST_MPLAYER_FROM;
 
-typedef enum {
-	PUSH_BUTTON_MPLAYER_NONE = 0,
-	PUSH_BUTTON_MPLAYER_PLAY,
-	PUSH_BUTTON_MPLAYER_PAUSE,
-	PUSH_BUTTON_MPLAYER_STOP
-
-} PUSH_BUTTON_MPLAYER;
-
-// typedef struct {
-// 	gchar *str;
-// } MPLAYER_ARGS;
+#define	MAX_PLAYERS_ARGS	100
 
 typedef struct {
 	gdouble			PercentTempsActuel;		// Temps actuel
 	gdouble			DOUBLE_TempsTotal;		// Temps Total
 	gdouble		 	DOUBLE_TempsTotalSection;
-	
-	// PUSH_BUTTON_MPLAYER	TypeButtonPush;			// Le type d'action/bouton
 	gboolean		BoolIsPause;			// TRUE = PAUSE | FALSE = NO PAUSE
-	
 	LIST_MPLAYER_FROM	ListPlayFrom;			// From dvd, cd, fichier
-	
-	gchar			*PlayerArgs [ 100 ];		// ... pour exec PlayerArgs
-	
+	gchar			*PlayerArgs[ MAX_PLAYERS_ARGS ];// Tableau de pointeurs pour les parametres
 	gboolean		BoolThreadActivate;		// TRUE is activate else FALSE
 	pthread_t		NmrTid;				// Numero de process du thread
 	gboolean		BoolTimeoutActivate;		// TRUE is activate else FALSE
@@ -69,13 +51,11 @@ typedef struct {
 	gint			Tube [ 2 ];			// Les tickets
 	pid_t			CodeFork;			// Numero de process pour mplayer
 	gboolean		BoolErreurMplayer;		// TRUE is erreur else FALSE
-	
 	gint			Button;				// -1, GDK_BUTTON_PRESS, GDK_BUTTON_RELEASE
 	void			(*FuncWinClose) (void);		// 
 	void			(*FuncSetValueTime) (gdouble p_value);
 	void			(*FuncIconeStop) (void);	// 
 	gboolean		(*Func_request_stop) (void);	// 
-	
 } VAR_MPLAYER;
 
 extern VAR_MPLAYER VarMplayer;
