@@ -241,112 +241,112 @@ gboolean options_get_entry_is_valid (TYPE_CONV p_verif_conv)
 // void options_default_values (GtkButton *button)
 void on_button_defaut_convertisseur_clicked (GtkButton *button, gpointer user_data)
 {
-	PRINT_FUNC_LF();
+	// PRINT_FUNC_LF();
 
 	if (button == GTK_BUTTON (GLADE_GET_OBJECT("button_defaut_lame"))) {
 		// g_print("\tbutton_defaut_lame\n");
 		// BitrateLameIndice
-		g_print("\t\tConfig.BitrateLameIndice = %d -> %d\n",Config.BitrateLameIndice, ConfigSaveToRest.BitrateLameIndice);
+		// g_print("\t\tConfig.BitrateLameIndice = %d -> %d\n",Config.BitrateLameIndice, ConfigSaveToRest.BitrateLameIndice);
 		Config.BitrateLameIndice = ConfigSaveToRest.BitrateLameIndice;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_abr_cbr_vbr), Config.BitrateLameIndice);
 		// TabBitrateLame
-		g_print("\t\tConfig.TabBitrateLame    = %d -> %d\n",Config.TabBitrateLame [ Config.BitrateLameIndice ], ConfigSaveToRest.TabBitrateLame [ ConfigSaveToRest.BitrateLameIndice ]);
+		// g_print("\t\tConfig.TabBitrateLame    = %d -> %d\n",Config.TabBitrateLame [ Config.BitrateLameIndice ], ConfigSaveToRest.TabBitrateLame [ ConfigSaveToRest.BitrateLameIndice ]);
 		Config.TabBitrateLame [ Config.BitrateLameIndice ] = ConfigSaveToRest.TabBitrateLame [ ConfigSaveToRest.BitrateLameIndice ];
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_bitrate), Config.TabBitrateLame [ Config.BitrateLameIndice ]);
 		// TabModeLame
-		g_print("\t\tConfig.TabModeLame       = %d -> %d\n",Config.TabModeLame [ Config.BitrateLameIndice ], ConfigSaveToRest.TabModeLame [ ConfigSaveToRest.BitrateLameIndice ]);
+		// g_print("\t\tConfig.TabModeLame       = %d -> %d\n",Config.TabModeLame [ Config.BitrateLameIndice ], ConfigSaveToRest.TabModeLame [ ConfigSaveToRest.BitrateLameIndice ]);
 		Config.TabModeLame [ Config.BitrateLameIndice ] = ConfigSaveToRest.TabModeLame [ ConfigSaveToRest.BitrateLameIndice ];
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Lame_Mode), Config.TabModeLame [ Config.BitrateLameIndice ]);
 	}
 	else if (button == GTK_BUTTON (GLADE_GET_OBJECT("button_defaut_oggenc"))) {
-		g_print("\tbutton_defaut_oggenc\n");
+		// g_print("\tbutton_defaut_oggenc\n");
 		// BitrateOggenc
-		g_print("\t\tConfig.BitrateOggenc = %d -> %d\n",Config.BitrateOggenc, ConfigSaveToRest.BitrateOggenc);
+		// g_print("\t\tConfig.BitrateOggenc = %d -> %d\n",Config.BitrateOggenc, ConfigSaveToRest.BitrateOggenc);
 		Config.BitrateOggenc = ConfigSaveToRest.BitrateOggenc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_bitrate), Config.BitrateOggenc);
 		// ManagedOggenc
-		g_print("\t\tConfig.ManagedOggenc = %d -> %d\n",Config.ManagedOggenc, ConfigSaveToRest.ManagedOggenc);
+		// g_print("\t\tConfig.ManagedOggenc = %d -> %d\n",Config.ManagedOggenc, ConfigSaveToRest.ManagedOggenc);
 		Config.ManagedOggenc = ConfigSaveToRest.ManagedOggenc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_managed), Config.ManagedOggenc);
 		// DownmixOggenc
-		g_print("\t\tConfig.DownmixOggenc = %d -> %d\n",Config.DownmixOggenc, ConfigSaveToRest.DownmixOggenc);
+		// g_print("\t\tConfig.DownmixOggenc = %d -> %d\n",Config.DownmixOggenc, ConfigSaveToRest.DownmixOggenc);
 		Config.DownmixOggenc = ConfigSaveToRest.DownmixOggenc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Oggenc_downmix), Config.DownmixOggenc);
 	}
 	else if (button == GTK_BUTTON (GLADE_GET_OBJECT("button_defaut_flac"))) {
-		g_print("\tbutton_defaut_flac\n");
+		// g_print("\tbutton_defaut_flac\n");
 		// CompressionLevelFlac
-		g_print("\t\tConfig.CompressionLevelFlac = %d -> %d\n", Config.CompressionLevelFlac, ConfigSaveToRest.CompressionLevelFlac);
+		// g_print("\t\tConfig.CompressionLevelFlac = %d -> %d\n", Config.CompressionLevelFlac, ConfigSaveToRest.CompressionLevelFlac);
 		Config.CompressionLevelFlac = ConfigSaveToRest.CompressionLevelFlac;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_flac_compression), Config.CompressionLevelFlac);
 	}
 	else if (button == GTK_BUTTON (GLADE_GET_OBJECT("button_defaut_mac"))) {
-		g_print("\tbutton_defaut_mac\n");
+		// g_print("\tbutton_defaut_mac\n");
 		// CompressionLevelApeMac
-		g_print("\t\tConfig.CompressionLevelApeMac = %d -> %d\n",Config.CompressionLevelApeMac, ConfigSaveToRest.CompressionLevelApeMac);
+		// g_print("\t\tConfig.CompressionLevelApeMac = %d -> %d\n",Config.CompressionLevelApeMac, ConfigSaveToRest.CompressionLevelApeMac);
 		Config.CompressionLevelApeMac = ConfigSaveToRest.CompressionLevelApeMac;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_ape_compression), Config.CompressionLevelApeMac);
 	}
 	else if (button == GTK_BUTTON (GLADE_GET_OBJECT("button_defaut_wavpack"))) {
-		g_print("\tbutton_defaut_wavpack\n");
+		// g_print("\tbutton_defaut_wavpack\n");
 		// CompressionWavpack
-		g_print("\t\tConfig.CompressionWavpack        = %d -> %d\n", Config.CompressionWavpack, ConfigSaveToRest.CompressionWavpack);
-		Config.CompressionWavpack = ConfigSaveToRest.CompressionWavpack;
+		// g_print("\t\tConfig.CompressionWavpack        = %d -> %d\n", Config.CompressionWavpack, ConfigSaveToRest.CompressionWavpack);
+		// Config.CompressionWavpack = ConfigSaveToRest.CompressionWavpack;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_wavpack), Config.CompressionWavpack);
 		// SoundWavpack
-		g_print("\t\tConfig.SoundWavpack              = %d -> %d\n", Config.SoundWavpack, ConfigSaveToRest.SoundWavpack);
+		// g_print("\t\tConfig.SoundWavpack              = %d -> %d\n", Config.SoundWavpack, ConfigSaveToRest.SoundWavpack);
 		Config.SoundWavpack = ConfigSaveToRest.SoundWavpack;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_wavpack_sound), Config.SoundWavpack);
 		// ModeHybrideWavpack
-		g_print("\t\tConfig.ModeHybrideWavpack        = %d -> %d\n", Config.ModeHybrideWavpack, ConfigSaveToRest.ModeHybrideWavpack);
+		// g_print("\t\tConfig.ModeHybrideWavpack        = %d -> %d\n", Config.ModeHybrideWavpack, ConfigSaveToRest.ModeHybrideWavpack);
 		Config.ModeHybrideWavpack = ConfigSaveToRest.ModeHybrideWavpack;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_wavpack_mode_hybride), Config.ModeHybrideWavpack);
 		// CorrectionFileWavpack
-		g_print("\t\tConfig.CorrectionFileWavpack     = %d -> %d\n", Config.CorrectionFileWavpack, ConfigSaveToRest.CorrectionFileWavpack);
+		// g_print("\t\tConfig.CorrectionFileWavpack     = %d -> %d\n", Config.CorrectionFileWavpack, ConfigSaveToRest.CorrectionFileWavpack);
 		Config.CorrectionFileWavpack = ConfigSaveToRest.CorrectionFileWavpack;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_wavpack_correction_file), Config.CorrectionFileWavpack);
 		// CompressionMaximumWavpack
-		g_print("\t\tConfig.CompressionMaximumWavpack = %d -> %d\n", Config.CompressionMaximumWavpack, ConfigSaveToRest.CompressionMaximumWavpack);
+		// g_print("\t\tConfig.CompressionMaximumWavpack = %d -> %d\n", Config.CompressionMaximumWavpack, ConfigSaveToRest.CompressionMaximumWavpack);
 		Config.CompressionMaximumWavpack = ConfigSaveToRest.CompressionMaximumWavpack;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_wavpack_maximum_compression), Config.CompressionMaximumWavpack);
 		// SignatureMd5Wavpack
-		g_print("\t\tConfig.SignatureMd5Wavpack       = %d -> %d\n", Config.SignatureMd5Wavpack, ConfigSaveToRest.SignatureMd5Wavpack);
+		// g_print("\t\tConfig.SignatureMd5Wavpack       = %d -> %d\n", Config.SignatureMd5Wavpack, ConfigSaveToRest.SignatureMd5Wavpack);
 		Config.SignatureMd5Wavpack = ConfigSaveToRest.SignatureMd5Wavpack;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_wavpack_signature_md5), Config.SignatureMd5Wavpack);
 		// ExtraEncodingWavpack
-		g_print("\t\tConfig.ExtraEncodingWavpack      = %d -> %d\n", Config.ExtraEncodingWavpack, ConfigSaveToRest.ExtraEncodingWavpack);
+		// g_print("\t\tConfig.ExtraEncodingWavpack      = %d -> %d\n", Config.ExtraEncodingWavpack, ConfigSaveToRest.ExtraEncodingWavpack);
 		Config.ExtraEncodingWavpack = ConfigSaveToRest.ExtraEncodingWavpack;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_wavpack_extra_encoding), Config.ExtraEncodingWavpack);
 	}
 	else if (button == GTK_BUTTON (GLADE_GET_OBJECT("button_defaut_musepack"))) {
-		g_print("\tbutton_defaut_musepack\n");
-		g_print("\t\tConfig.QualityMppenc = %d -> %d\n", Config.QualityMppenc, ConfigSaveToRest.QualityMppenc);
+		// g_print("\tbutton_defaut_musepack\n");
+		// g_print("\t\tConfig.QualityMppenc = %d -> %d\n", Config.QualityMppenc, ConfigSaveToRest.QualityMppenc);
 		// QualityMppenc
 		Config.QualityMppenc = ConfigSaveToRest.QualityMppenc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_Mppenc), Config.QualityMppenc);
 	}
 	else if (button == GTK_BUTTON (GLADE_GET_OBJECT("button_defaut_faac"))) {
-		g_print("\tbutton_defaut_faac\n");
-		g_print("\t\tConfig.ConteneurFacc = %d -> %d\n", Config.ConteneurFacc, ConfigSaveToRest.ConteneurFacc);
+		// g_print("\tbutton_defaut_faac\n");
+		// g_print("\t\tConfig.ConteneurFacc = %d -> %d\n", Config.ConteneurFacc, ConfigSaveToRest.ConteneurFacc);
 		// ConteneurFacc
 		Config.ConteneurFacc = ConfigSaveToRest.ConteneurFacc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_conteneur), Config.ConteneurFacc);
-		g_print("\t\tConfig.AbrVbrFacc    = %d -> %d\n", Config.AbrVbrFacc, ConfigSaveToRest.AbrVbrFacc);
+		// g_print("\t\tConfig.AbrVbrFacc    = %d -> %d\n", Config.AbrVbrFacc, ConfigSaveToRest.AbrVbrFacc);
 		// AbrVbrFacc
 		Config.AbrVbrFacc = ConfigSaveToRest.AbrVbrFacc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_choice_vbr_abr), Config.AbrVbrFacc);
-		g_print("\t\tConfig.VbrFaccIndice = %d -> %d\n", Config.VbrFaccIndice, ConfigSaveToRest.VbrFaccIndice);
+		// g_print("\t\tConfig.VbrFaccIndice = %d -> %d\n", Config.VbrFaccIndice, ConfigSaveToRest.VbrFaccIndice);
 		// VbrFaccIndice
 		Config.VbrFaccIndice = ConfigSaveToRest.VbrFaccIndice;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_faac_set_choice_vbr_abr), Config.VbrFaccIndice);
 	}
 	else if (button == GTK_BUTTON (GLADE_GET_OBJECT("button_defaut_aacplusenc"))) {
-		g_print("\tbutton_defaut_aacplusenc\n");
-		g_print("\t\tConfig.ChoiceMonoAacplusenc   = %d -> %d\n", Config.ChoiceMonoAacplusenc, ConfigSaveToRest.ChoiceMonoAacplusenc);
+		// g_print("\tbutton_defaut_aacplusenc\n");
+		// g_print("\t\tConfig.ChoiceMonoAacplusenc   = %d -> %d\n", Config.ChoiceMonoAacplusenc, ConfigSaveToRest.ChoiceMonoAacplusenc);
 		// ChoiceMonoAacplusenc
 		Config.ChoiceMonoAacplusenc = ConfigSaveToRest.ChoiceMonoAacplusenc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_aacplusenc_mono), Config.ChoiceMonoAacplusenc);
-		g_print("\t\tConfig.ChoiceStereoAacplusenc = %d -> %d\n", Config.ChoiceMonoAacplusenc, ConfigSaveToRest.ChoiceStereoAacplusenc);
+		// g_print("\t\tConfig.ChoiceStereoAacplusenc = %d -> %d\n", Config.ChoiceMonoAacplusenc, ConfigSaveToRest.ChoiceStereoAacplusenc);
 		// ChoiceStereoAacplusenc
 		Config.ChoiceStereoAacplusenc = ConfigSaveToRest.ChoiceStereoAacplusenc;
 		gtk_combo_box_set_active (GTK_COMBO_BOX (var_options.Adr_Widget_aacplusenc_stereo), Config.ChoiceStereoAacplusenc);
