@@ -93,12 +93,12 @@
 	*/
 	
 typedef enum {
-	CD_TAG_ARTIST = 0,
-	CD_TAG_ALBUM,
-	CD_TAG_INT_NUMBER,
-	CD_TAG_TITLE,
-	CD_TAG_YEAR,
-	CD_TAG_GENRE,
+	CD_TAG_ARTIST = 0,			// 
+	CD_TAG_ALBUM,				// 
+	CD_TAG_INT_NUMBER,			// 
+	CD_TAG_TITLE,				// 
+	CD_TAG_YEAR,				// 
+	CD_TAG_GENRE,				// 
 	CD_TAG_FILE_M3U_XSPF,			// BoolCreateFileM
 	CD_TAG_CAR_REPLACE,			// StringReplace
 	CD_TAG_TETSUMAKI_LOWER,			// TOUTES LES LETTRES EN MINUSCULE SAUF LA PREMIERE ANSI QUE LES CARACTERES PRECEDES PAR '%'
@@ -125,7 +125,9 @@ VAR_PARSE VarParse = { NULL, NULL };
 
 
 
-// DEBUGING ...
+/*
+//
+// DEBUGING PARSE
 //
 void Parse_debug (PARSE_TYPE p_ParseType)
 {
@@ -151,8 +153,8 @@ void Parse_debug (PARSE_TYPE p_ParseType)
 		list = g_list_next (list);
 	}
 }
-
-// DEBUGING ...
+//
+// DEBUGING PARSE
 //
 void Parse_debug_print_cd (PARSE_TYPE p_ParseType)
 {
@@ -166,7 +168,8 @@ void Parse_debug_print_cd (PARSE_TYPE p_ParseType)
 		Str = NULL;
 	}
 }
-
+*/
+// 
 // SUPRESSION DES STRUCTURES ET DES GLIST
 //
 void Parse_remove (PARSE_TYPE p_ParseType)
@@ -182,8 +185,6 @@ void Parse_remove (PARSE_TYPE p_ParseType)
 	while(  list ) {
 		if( (Parse = (PARSE *)list->data) != NULL ) {
 			switch (Parse->CdTypeTag ) {
-			// case CD_TAG_ARTIST :
-			// case CD_TAG_ALBUM :
 			case CD_TAG_INT_NUMBER :
 			case CD_TAG_TITLE :
 			case CD_TAG_YEAR :
@@ -227,7 +228,7 @@ void Parse_remove (PARSE_TYPE p_ParseType)
 		VarParse.ListParseTitleCd = NULL;
 	}
 }
-
+// 
 // ALLOCATION ET STOCKAGE DE TOUS LES TYPES SAUF: CD_TAG_CAR_REPLACE
 // 
 void Parse_allocate (PARSE_TYPE p_ParseType, CD_TYPE_TAG p_CdTypeTag, gchar *p_Str)
@@ -259,7 +260,7 @@ void Parse_allocate (PARSE_TYPE p_ParseType, CD_TYPE_TAG p_CdTypeTag, gchar *p_S
 		VarParse.ListParseTitleCd = g_list_append (VarParse.ListParseTitleCd, New);
 	}
 }
-
+// 
 // ALLOCATION ET STOCKAGE DU TYPE: CD_TAG_CAR_REPLACE
 // 
 void Parse_allocate_function (PARSE_TYPE p_ParseType, CD_TYPE_TAG p_CdTypeTag, gchar *p_Str)
@@ -270,8 +271,6 @@ void Parse_allocate_function (PARSE_TYPE p_ParseType, CD_TYPE_TAG p_CdTypeTag, g
 	PARSE	*New = NULL;
 	gchar	Str [ 10 ];
 		
-	// PRINT_FUNC_LF();
-	
 	// LE CARACTERE DE REMPLACEMENT
 	while(  PtrEnd && *PtrEnd) PtrEnd ++;
 	PtrEnd --;
@@ -320,7 +319,7 @@ void Parse_allocate_function (PARSE_TYPE p_ParseType, CD_TYPE_TAG p_CdTypeTag, g
 		else	Ptr ++;
 	}
 }
-
+// 
 // SUPPRESSION ET PARSE COMPLET
 // 
 void Parse_entry (PARSE_TYPE p_ParseType)
@@ -766,7 +765,6 @@ gchar *Parse_get_line (PARSE_TYPE p_ParseType, gint p_Num_cell)
 			Ptr ++;
 		}
 	}
-	
 	Str = g_strdup (gstr->str);
 	g_string_free (gstr, TRUE);
 	gstr = NULL;
