@@ -52,6 +52,7 @@
 #include "play_file.h"
 
 
+
 typedef struct {
 	pthread_t	 nmr_tid;
 	gchar		*Playeur;
@@ -59,9 +60,18 @@ typedef struct {
 	gchar		*PathNameFile;
 } VAR_PLAYFILE ;
 
-VAR_PLAYFILE PlayFile;
+VAR_PLAYFILE PlayFile = {
+		0,		// 
+		NULL,		// 
+		NULL,		// 
+		NULL		// 
+		};
 
 
+
+// 
+// 
+// 
 void PlayFile_call (void)
 {
 	pid_t  pid;
@@ -83,13 +93,15 @@ void PlayFile_call (void)
 		_exit (0);
 	}
 }
-
+// 
+// 
 static void PlayFile_thread (void *arg)
 {
 	PlayFile_call ();
 	pthread_exit(0);
 }
-
+// 
+// 
 void PlayFile_play (gchar *PathNameFile)
 {
 	PRINT_FUNC_LF();
