@@ -60,7 +60,7 @@
 #include "dragNdrop.h"
 #include "fileselect.h"
 #include "configuser.h"
-#include "cd_cddb.h"
+#include "cd_curl.h"
 #include "poche.h"
 
 
@@ -923,7 +923,7 @@ IMAGE *poche_add_to_glist( gchar *PathNameFile, gdouble x, gdouble y, gboolean p
 	
 		// _TYPE_TEXT_TITLE_
 		// _TYPE_TEXT_
-		New->Texte              = g_strdup_printf( "\n Test %d", g_list_length( view.ListImage ));
+		New->Texte              = g_strdup_printf( "\n Write text %d", g_list_length( view.ListImage ));
 		New->FontName           = g_strdup( "Sans" );
 		New->SizeFontName       = 8;
 		New->BoolFontBold       = FALSE;
@@ -1099,7 +1099,8 @@ void poche_remove_image( void )
 				}
 				gtk_widget_queue_draw( view.AdrDrawingarea );
 				poche_set_flag_buttons();
-				CdCddb_set_combobox_choice( 0 );
+				// DEBUG CDDB_CURL
+				pochetxt_set_combobox_choice( 0 );
 				break;
 			}
 		}
