@@ -59,9 +59,7 @@
 #include "cursor.h"
 #include "dragNdrop.h"
 #include "fileselect.h"
-// #include "popup.h"
 #include "configuser.h"
-#include "cd_cddb.h"
 #include "poche.h"
 
 
