@@ -28,25 +28,27 @@
 #ifndef popup_h
 #define popup_h 1
 
-#include "file.h"
+
 #include "cd_audio.h"
 
-void	popup_normalise_dvd (void);
 
 void	popup_cd (CD_AUDIO *Audio, TYPE_FILE_IS TypeFileIs);
-void	popup_normalise_cd (void);
-
-void	popup_trash (void);
 void	popup_file (DETAIL *detail, TYPE_FILE_IS TypeFileIs);
 void	popup_file_ReplayGain (DETAIL *detail);
-
 void	popup_file_wav_frequence (DETAIL *detail);
 void	popup_file_wav_piste (DETAIL *detail);
 void	popup_file_wav_quantification (DETAIL *detail);
 
-void	popup_file_Split (void);
 
-void	popup_for_pocheevent (gboolean bool_recto);
+#include "poche.h"
+
+void	popup_file_Split (void);
+void	popup_flip( IMAGE *p_Image );
+void	popup_viewport( GLIST_POCHETTE *gl );
+void	popup_trash (void);
+void	popup_normalise_cd (void);
+void	popup_normalise_dvd (void);
+
 
 #endif
 
