@@ -111,6 +111,17 @@ NULL,								// PIXBUF TREE-VIEW
 " cdparanoia",							// PAQUAGE
 gettext_noop(" Extracteur cd audio")},				// DESCRIPTION
 
+{"cd-discid",							// PACKAGEDEBIAN_64
+"cd-discid",							// PACKAGEDEBIAN_32
+"cd-discid",							// NAME1
+"",								// NAME2
+"",								// NAME3
+&PrgInit.bool_cd_discid,					// FOUND
+NULL,								// NAME TREE-VIEW
+NULL,								// PIXBUF TREE-VIEW
+" cd-discid",							// PAQUAGE
+gettext_noop(" Read CD and get CDDB discid information")},	// DESCRIPTION
+
 {"checkmp3",							// PACKAGEDEBIAN_64
 "checkmp3",							// PACKAGEDEBIAN_32
 "mp3check",							// NAME1
@@ -348,7 +359,8 @@ gettext_noop(" WAVPACK  Hybrid Lossless Audio Compressor")}	// DESCRIPTION
 
 
 
-// LES ELEMENTS DU TREEVIEW
+// 
+// CHERCHE LA DISTRIBUTION EN RAPPORT AVEC LE PROGRAMME D' INSTALLATION
 // 
 void on_label_type_package_realize (GtkWidget *widget, gpointer user_data)
 {
@@ -395,12 +407,11 @@ void on_label_type_package_realize (GtkWidget *widget, gpointer user_data)
 	
 	if (widget != NULL && New_Str != NULL) {
 		gtk_label_set_markup (GTK_LABEL (var_options.Adr_label_type_paquege), New_Str);
-		// gtk_label_set_markup (GTK_LABEL (GTK_WIDGET (XCFA_GET_OBJECT("label_type_package_without_deb"))), New_Str);
 		g_free (New_Str);
 		New_Str = NULL;
 	}
 }
-// LES ELEMENTS DU TREEVIEW
+// GET INFOS FROM STRUCT
 // 
 gchar *prginit_get_name (TYPE_PROGINIT TypeEnum)
 {
@@ -412,14 +423,12 @@ GdkPixbuf *prginit_get_pixbuf (TYPE_PROGINIT TypeEnum)
 {
 	return ((GdkPixbuf *)TableauPrgExtern [ TypeEnum ] . Pixbuf);
 }
-
 // 
 // 
 gchar *prginit_get_Paquage (TYPE_PROGINIT TypeEnum)
 {
 	return ((gchar *)TableauPrgExtern [ TypeEnum ] . Paquage);
 }
-
 // 
 // 
 gchar *prginit_get_Description (TYPE_PROGINIT TypeEnum)
