@@ -26,7 +26,7 @@
 
 
 #ifndef process_h
-#define _process_h 1
+#define process_h 1
 
 #define XCFA_FILE_LOAD		"/tmp/xcfa_file_load.txt"
 
