@@ -67,16 +67,12 @@
 
 
 
-gboolean bool_print = TRUE;
 extern gint		 n_drag_types;			/* Drag And Drop	*/
 VAR_SPLIT VarSplit;
 ADJUST Adjust;
 
 void SetAjust (void);
 
-
-
-
 // 
 // PERCENT = ( VALUE_X / LONGUEUR_TOTALE ) * 100.0
 // VALUE_X = ( LONGUEUR_TOTALE * PERCENT ) / 100.0
@@ -461,7 +457,7 @@ void split_file_load_continue (gchar *p_PathNameFile)
 		VarSplit.BoolInThread = TRUE;
 		PRINT("DEBUT TIMEOUT SPLIT");
 		PRINT("DEBUT THREAD SPLIT");
-		VarSplit.HandlerTimeoutDo = gtk_timeout_add (5, VarSplit_timeout, 0);
+		VarSplit.HandlerTimeoutDo = gtk_timeout_add (100, VarSplit_timeout, 0);
 		pthread_create (&nmr_tid, NULL ,(void *)VarSplit_thread, (void *)NULL);
 	}
 	else {
@@ -594,10 +590,10 @@ void split_set_value (gdouble p_value)
 	    (gint)VarSplit.AdjScroll->value < SplitSpectre_get_with() ) {
 		SplitSpectre_scroll_droite_play ();
 	}
-	
 	split_set_time ();
-	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
+	SplitSpectre_draw_lines_play();
+	// gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 }
 // 
 // 
@@ -1012,7 +1008,7 @@ void on_image_split_spectre_realize (GtkWidget *widget, gpointer user_data)
 			drag_types, n_drag_types,
 			GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_DEFAULT
 			);
-
+	
 	VarSplit.BoolEventButtonPressSpectre = FALSE;
 	VarSplit.BoolReadFileSpectre         = FALSE;
 	VarSplit.PathNameFile                = NULL;
@@ -1048,7 +1044,6 @@ void on_image_split_spectre_realize (GtkWidget *widget, gpointer user_data)
 // 
 gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
-	// static gint Nbr = 0;
 	gboolean		BoolEventTypeScroll = (GDK_SCROLL == event->type) ? TRUE : FALSE;
 	gint			EventTypeScrollDirection = ((GdkEventScroll*)event)->direction;
 	gint			CursorX, _CursorX, CursorY;
@@ -1059,11 +1054,17 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 	
 	// PRINT_FUNC_LF();
 	
+	// IMPOSER UN REAFFICHAGE COMPLET
+	// g_print( "event->type = %d\n", event->type );
+	if( 29 == event->type ) {
+		gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
+		// return FALSE;
+	}
+	
  	if (VarSplit.NbrSelecteurs > 1 && GDK_BUTTON_PRESS == event->type && TRUE == bool_click_droit && VarSplit.NbrSelecteurs > 0) {
 		popup_file_Split ();
 		return FALSE;
 	}
-	// g_print("\tNbr = %d\n",Nbr++);
 	
 	Adjust.with           = SplitSpectre_get_with();
 	Adjust.lower          = VarSplit.AdjScroll->lower;
@@ -1163,7 +1164,6 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 	
 	// UN CLICK BOUTON SOURIS : PRESSED
 	else if (TRUE == bool_click_gauche && event->type == GDK_BUTTON_PRESS) {
-		
 		if (VarSplit.TypeCursorSpectre == _CURSOR_IS_LEFT_ ||
 		    VarSplit.TypeCursorSpectre == _CURSOR_IS_RIGHT_ ||
 		    VarSplit.TypeCursorSpectre == _CURSOR_IS_HAND_) {
@@ -1178,6 +1178,8 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 			AlsaPlay_fseek( VarSplit.PercentActivePlay );
 		}
 		VarSplit.BoolEventButtonPressSpectre = TRUE;
+		// 1 000 000 = 1 seconde
+		// g_usleep( 150000 );
 	}
 	
 	// GESTION CLICK BOUTON SOURIS : RELEASE
@@ -1194,20 +1196,21 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 			}
 			else if (VarSplit.TypeCursorSpectre == _CURSOR_IS_RIGHT_) {
 				SplitSelector_set_pos_end( _CursorX );
-			}		
+			}
 			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
 			cursor_set_old ();
 			VarSplit.TypeCursorSpectre = _CURSOR_IS_NONE_;
 		}
 		split_set_name_file ();
+		// g_usleep( 500000 );
 	}
 	
 	// MOVE CURSEUR
 	if (TRUE == VarSplit.BoolEventButtonPressSpectre && TRUE == bool_click_gauche) {
 	
 		gint	end      = VARSPLIT_SPECTRE_WITH + (gint)VarSplit.AdjScroll->value;
-		
+	
 		// SCROLL RIGHT
 		if( (gint)VarSplit.AdjScroll->value >= 0 && _CursorX >= end ) {
 			rigtht_plus_scrolled ();
@@ -1237,12 +1240,15 @@ gboolean on_eventbox_splitspectre_event (GtkWidget *widget, GdkEvent *event, gpo
 			SplitSelector_set_pos_end( _CursorX );
 			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
 			gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreTop );
-		}		
+		}
 		split_set_time ();
 	}
 	
-	
 	split_set_flag_buttons ();
+	
+	if( 4 == event->type || 7 == event->type  || 29 == event->type ) {
+		// gtk_widget_queue_draw( VarSplit.AdrWidgetSpectre );
+	}
 	gtk_widget_queue_draw( VarSplit.AdrWidgetSpectreChrono );
 
 	return FALSE;
