@@ -146,10 +146,10 @@ typedef struct {								// SPECIFICATION D'UN SELECTEUR
 
 
 typedef enum {
-	_CURSOR_IS_NONE_ = 0,
-	_CURSOR_IS_LEFT_,
-	_CURSOR_IS_RIGHT_,
-	_CURSOR_IS_HAND_
+	_CURSOR_IS_NONE_ = 0,							// 
+	_CURSOR_IS_LEFT_,							// 
+	_CURSOR_IS_RIGHT_,							// 
+	_CURSOR_IS_HAND_							// 
 } TYPE_CURSOR;
 
 /*
@@ -170,26 +170,18 @@ typedef struct {
 	GtkWidget		*AdrWidgetSpectre;				// Adr Widget Spectre
 	GtkWidget		*AdrWidgetSpectreChrono;			// Adr Widget Spectre Chrono
 	GtkWidget		*AdrWidgetSpectreTop;				// Adr Widget Spectre Chrono
-	
 	GtkButton		*Adr_button_destination;			// Adr du widget de la destinations des decoupes
-	
 	gint			NbrSelecteurs;					// Nombre total de selecteurs
 	SELECTEUR		Selecteur [ MAX_SELECTEURS_SPLIT +2 ];		// Tableau des selecteurs
 	gint			SelecteurActif;					// Le selecteur actif si NbrSelecteurs > -1
-	
 	gboolean		BoolReadFileSpectre;				// TRUE = BoolReadFileSpectre else NONE
-	
 	gdouble			TimeSongSec;					// Duree totale du fichier en secondes
-	
 	void			(*FuncExternBegin) (gdouble Percent);		// Rappel modif pointeur DEBUT
 	void			(*FuncExternEnd) (gdouble Percent);		// Rappel modif pointeur FIN
 	void			(*FuncExternWaitPlay) (void);			// Rappel selection d'ecoute
 	void			(*FuncExternStopPlay) (void);			// Rappel fin d'ecoute
-	
 	gdouble			PercentActivePlay;				// Pointeur de lecture audio
-	
 	gboolean		BoolEventButtonPressSpectre;			// 
-	
 	POINTS_FILE		*Tab;						// Tableau des amplitudes du fichier actif
 	glong			TotalAllocation;				// Longeur du tableau Tab
 	gint			MaxPointsInTab;					// 
@@ -199,30 +191,22 @@ typedef struct {
 	GdkPoint		*MinScale_1;					// 
 	GdkPoint		*MaxScale_2;					// 
 	GdkPoint		*MinScale_2;					// 
-	
 	glong			TotalAllocationTabScreen;			// Longeur du tableau TabScreen
 	gshort			nBitsPerSample;					// 8 16 24 et 32
 	gint			nTotalChunckSize;				// Taille des données
-	
 	gchar			*PathNameFile;					// Nom complet du fichier
 	gchar			*PathNameFileReal;				// Nom reel du fichier
 	TYPE_FILE_IS		TypeFileIs;					// WAV,  MP3, OGG, FLAC, SHN, WAVPACK
 	INFO_WAV		*Tags;						// 
-	
-	gboolean		BoolInThread;
-	guint			HandlerTimeoutDo;
-	
+	gboolean		BoolInThread;					//
+	guint			HandlerTimeoutDo;				//
 	TYPE_CURSOR		TypeCursorSpectre;				// NONE | LEFT | RIGHT
-	
 	gboolean		BoolPlay;					// FALSE -> TRUE -> FALSE
-	
 	gboolean		BoolQueueDrawSpectre;				// 
 	gboolean		BoolQueueDrawChrono;				// 
 	gboolean		BoolQueueDrawTop;				// 
-	GtkAdjustment		*AdjScroll;
-	
+	GtkAdjustment		*AdjScroll;					//
 	gboolean		BoolBlankWithCue;				// 
-	
 } VAR_SPLIT;
 
 
@@ -245,16 +229,22 @@ typedef struct {
 
 
 typedef struct {
-	gfloat	value;
-	gfloat	lower;
-	gfloat	upper;
-	gfloat	step_increment;
-	gfloat	page_size;
-	gfloat	page_increment;
-	gint	with;
-	gint	mul;
+	gfloat	value;								// 
+	gfloat	lower;								// 
+	gfloat	upper;								// 
+	gfloat	step_increment;							// 
+	gfloat	page_size;							// 
+	gfloat	page_increment;							// 
+	gint	with;								// 
+	gint	mul;								// 
 } ADJUST;
 
+// 
+// ---------------------------------------------------------------------------
+//  SPLIT_SPECTRE.C
+// ---------------------------------------------------------------------------
+// 
+void		SplitSpectre_draw_lines_play( void );
 gboolean	SplitSpectre_read_file_spectre (gchar *PathNameFile);
 void		SplitSpectre_draw_lines (void);
 void		SplitSpectre_realize (GtkWidget *widget);
@@ -263,7 +253,11 @@ void		SplitSpectre_draw_chrono ( GtkWidget *widget );
 void		SplitSpectre_draw_top ( GtkWidget *widget );
 gint		SplitSpectre_get_with (void);
 void		SplitSpectre_remove (void);
-
+// 
+// ---------------------------------------------------------------------------
+//  SPLIT.C
+// ---------------------------------------------------------------------------
+// 
 void		split_file_load_continue (gchar *p_PathNameFile);
 void		split_load_from_dnd (GSList *p_list);
 void		split_set_name_file (void);
@@ -271,7 +265,11 @@ void		split_play (void);
 void		split_set_stop (void);
 void		split_from_popup (gint p_choice);
 void		split_set_flag_buttons (void);
-
+// 
+// ---------------------------------------------------------------------------
+//  SPLIT_SELECTOR.C
+// ---------------------------------------------------------------------------
+// 
 void		SplitSelector_init (void);
 void		SplitSelector_cut (void);
 void		SplitSelector_add (gint p_CursorX);
@@ -289,9 +287,17 @@ gboolean	SplitSelector_cursor_in_line_play (gint p_cursor_x, gint p_cursor_y);
 gint		SplitSelector_get_pos_play (void);
 void		SplitSelector_set_pos_play (gint p_play);
 gint		SplitSelector_get_diff_sec (gdouble p_PercentBegin, gdouble p_PercentEnd);
-
+// 
+// ---------------------------------------------------------------------------
+//  SPLIT_CUE.C
+// ---------------------------------------------------------------------------
+// 
 gchar		*SplitCue_read_cue_file (gchar *p_pathname);
-
+// 
+// ---------------------------------------------------------------------------
+//  SPLIT_CONV.C
+// ---------------------------------------------------------------------------
+// 
 void		SplitConv_to (gchar *p_PathNameFile);
 
 
