@@ -284,6 +284,8 @@ static gint SplitConv_timeout (gpointer data)
 		
 		gchar	*Str = NULL;
 		
+		// DEBUG
+		if( conv.total_percent > 1.0 ) conv.total_percent = 1.0;
 		Str = g_strdup_printf ("%d%%", (int)(conv.total_percent * 100));
 		WindScan_set_progress (Str, conv.total_percent);
 		g_free (Str);
@@ -304,12 +306,14 @@ static gint SplitConv_timeout (gpointer data)
 			}
 			else {
 				WindScan_close ();
-				wininfo_create (
-					_("Erreur SOX"),
-					_("Le programme SOX de votre distribution"),
-					"\n",
-					_("a generer une erreur pendant la conversion."),
-					"");
+				if( FALSE == WindScan_close_request()) {
+					wininfo_create (
+						_("Erreur SOX"),
+						_("Le programme SOX de votre distribution"),
+						"\n",
+						_("a generer une erreur pendant la conversion."),
+						"");
+				}
 			}
 		}
 		else {
@@ -318,12 +322,14 @@ static gint SplitConv_timeout (gpointer data)
 			}
 			else {
 				WindScan_close ();
-				wininfo_create (
-					_("Erreur SOX"),
-					_("Le programme SOX de votre distribution"),
-					"\n",
-					_("a generer une erreur pendant la conversion."),
-					"");
+				if( FALSE == WindScan_close_request()) {
+					wininfo_create (
+						_("Erreur SOX"),
+						_("Le programme SOX de votre distribution"),
+						"\n",
+						_("a generer une erreur pendant la conversion."),
+						"");
+				}
 			}
 		}
 		g_unlink (SPLIT_FILE_TMP_WAV_SOX);		
