@@ -127,7 +127,6 @@ void on_button_del_cut_split_clicked (GtkButton *button, gpointer user_data)
 // 
 void SplitSelector_cut (void)
 {
-#define	        MESS_ERR_CUT "Suppression pendant la lecture impossible"
 	if (0 == VarSplit.NbrSelecteurs) {
 		PRINT("\tAUCUN SELECTEUR  !!!");
 	}
@@ -137,7 +136,7 @@ void SplitSelector_cut (void)
 	else if (VarSplit.NbrSelecteurs > 1) {
 		
 		if (TRUE == AlsaPlay_is_play ()) {
-			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _(MESS_ERR_CUT) );
+			StatusBar_set_mess( NOTEBOOK_SPLIT, _STATUSBAR_WARN_, _("Suppression pendant la lecture impossible") );
 		}
 		else {
 			gint	Zone = 0;
