@@ -54,7 +54,7 @@ extern VAR_SPLIT VarSplit;
 extern ADJUST Adjust;
 
 
-
+gint	MarkerOld = -1;
 
 
 // 
@@ -92,7 +92,58 @@ void SplitSpectre_draw_chrono ( GtkWidget *widget )
 	gint			H, M, S, C;
 	gchar			*Str = NULL;
 	gint			hundr;
+	
+	/*
+	cairo_t		*cr;
+	
+	if (NULL == widget) return;
+	
+	cr = gdk_cairo_create( widget->window );
+	cairo_scale( cr, 1.0, 1.0 );
+	cairo_translate( cr, 0.0, 0.0 );
+	
+	// COLOR: 0 .. 255 -> PRG: colorname
+	gdouble	red, blue, green;
 		
+	// CLEAR  PREVIEW SURFACE
+	// CRAYON_GRIS
+	red   = 99
+	blue  = 99
+	green = 99
+	cairo_set_source_rgb( cr, red/255.0, green/255.0, blue/255.0 );
+	cairo_rectangle( cr,
+			 0,
+			 0,
+			 widget ->allocation.width,
+			 widget->allocation.height
+			 );			
+	cairo_fill( cr );
+	
+	// ECRITURE BARRE CHRONOLOGIQUE
+	// CRAYON_BLANC
+	red   = 255
+	blue  = 255
+	green = 255
+	cairo_set_source_rgb( cr, red/255.0, green/255.0, blue/255.0 );
+	
+#define  SPLIT_TIME_CHRONO_   80
+	for (ChronoX = 2; ChronoX +60 <= VARSPLIT_CHRONO_W +80; ChronoX += SPLIT_TIME_CHRONO_) {
+		if (ChronoX > 2) {
+			gdk_draw_line (
+				widget->window,
+				gc,
+				ChronoX -2,
+				VARSPLIT_CHRONO_Y,
+				ChronoX -2,
+				VARSPLIT_CHRONO_Y + VARSPLIT_CHRONO_H
+				);
+		}
+	}
+	
+	
+	cairo_paint( cr );
+	*/
+	
 	if (NULL == widget) return;
 
 	colormap = gdk_drawable_get_colormap (widget->window);
@@ -756,7 +807,7 @@ gboolean SplitSpectre_read_file_spectre (gchar *PathNameFile)
 					}
 					VarSplit.Tab [ points ].Min = min;
 					VarSplit.Tab [ points ].Max = max;
-					
+
 					points ++;
 				}
 				break;
@@ -831,9 +882,11 @@ void SplitSpectre_draw_lines (void)
 	gdouble			SpectreGetWith;
 	// static gint		Nbr = 0;
 	
+	// PRINT_FUNC_LF();
+	
 	// WAV if bitrate == 8 16 24 32
 	if (VarSplit.Tab != NULL && VarSplit.TypeFileIs == FILE_IS_WAV && VarSplit.MaxPointsInTab > 0) {
-			
+		
 		// PRINT_FUNC_LF();
 		// g_print( "\tNbr = %d\n", Nbr++ );
 		
@@ -953,7 +1006,7 @@ void SplitSpectre_draw_lines (void)
 		poly [ 1 ] . y = VARSPLIT_SPECTRE_Y;
 		poly [ 2 ] . x = VARSPLIT_SPECTRE_X + VARSPLIT_SPECTRE_W +1;
 		poly [ 2 ] . y = VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H +1;
-		poly [ 3 ] . x = VARSPLIT_SPECTRE_Y;
+		poly [ 3 ] . x = VARSPLIT_SPECTRE_X;
 		poly [ 3 ] . y = VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H +1;
 		poly [ 4 ] . x = VARSPLIT_SPECTRE_X;
 		poly [ 4 ] . y = VARSPLIT_SPECTRE_Y;
@@ -969,9 +1022,10 @@ void SplitSpectre_draw_lines (void)
 		SelBegin = SplitSelector_get_pos_begin (VarSplit.SelecteurActif);
 		SelEnd   = SplitSelector_get_pos_end (VarSplit.SelecteurActif);
 		begin    = save_begin;
-		
+				
 		for (points = 0; begin < end; begin ++, points ++) { 
 					
+			
 			// MaxScale_0
 			if (begin >= SelBegin &&  begin <= SelEnd) {
 				CRAYON_BLEU		// LA SELECTION
@@ -1013,7 +1067,6 @@ void SplitSpectre_draw_lines (void)
 					points,
 					VarSplit.MinScale_2 [ points ] . y
 					);
-		
 		}
 				
 		// AFFICHE CURSEUR DEBUT
@@ -1045,23 +1098,22 @@ void SplitSpectre_draw_lines (void)
 		
 		// AFFICHE LE CURSEUR AUDIO
 		if (VarSplit.PercentActivePlay >= 0.0) {
-			SelEnd = (gint)(((gdouble)SplitSpectre_get_with() * VarSplit.PercentActivePlay) / 100.0);
-			if (SelEnd >= save_begin && SelEnd < Len) {
-				SelEnd = (gint)(((gdouble)SplitSpectre_get_with() * VarSplit.PercentActivePlay) / 100.0);
+			MarkerOld = (gint)(((gdouble)SplitSpectre_get_with() * VarSplit.PercentActivePlay) / 100.0);
+			if (MarkerOld >= save_begin && MarkerOld < Len) {
 				CRAYON_ROUGE
 				gdk_draw_line (
 					VarSplit.AdrWidgetSpectre->window,
 					gc,
-					SelEnd - save_begin,
+					MarkerOld - save_begin,
 					VARSPLIT_SPECTRE_Y,
-					SelEnd - save_begin,
+					MarkerOld - save_begin,
 					VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H -2
 					);
 				gdk_draw_rectangle (
 					VarSplit.AdrWidgetSpectre->window,
 					gc,
 					TRUE,
-					SelEnd - save_begin -6,
+					MarkerOld - save_begin -6,
 					VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H -12,
 					14,
 					12
@@ -1072,7 +1124,163 @@ void SplitSpectre_draw_lines (void)
 		// CLOSE DRAW
 		gdk_gc_destroy (gc);
 	}
+}
+// AFFICHAGE DU CURSEUR EN MODE PLAY: GAN DE TEMPS POUR LE CPU
+//
+void SplitSpectre_draw_lines_play( void )
+{
+	GdkColor		gdk_color;
+	GdkColormap		*colormap;
+	GdkGC			*gc;
+	gint			points = 0;
+	gint			AdjValue;
+	gint			begin = 0;
+	gint			end = 0;
+	gint			save_begin = 0;
+	gint			SelBegin = 0;
+	gint			SelEnd = 0;
+	gint			Len;
+	gint			Marker;
 	
+	// WAV if bitrate == 8 16 24 32
+	if (VarSplit.Tab != NULL && VarSplit.TypeFileIs == FILE_IS_WAV && VarSplit.MaxPointsInTab > 0) {
+			
+		// PRINT_FUNC_LF();
+		
+		// OPEN DRAW
+		colormap = gdk_window_get_colormap (VarSplit.AdrWidgetSpectre->window);
+		gc = gdk_gc_new (VarSplit.AdrWidgetSpectre->window);
+			
+		// 
+		begin      = 
+		save_begin =
+		AdjValue   = (gint)VarSplit.AdjScroll->value;
+		Len        = 
+		end        = begin + VARSPLIT_SPECTRE_WITH;
+		
+		Marker   = (gint)(((gdouble)SplitSpectre_get_with() * VarSplit.PercentActivePlay) / 100.0);
+		SelBegin = SplitSelector_get_pos_begin (VarSplit.SelecteurActif);
+		SelEnd   = SplitSelector_get_pos_end (VarSplit.SelecteurActif);
+		begin    = save_begin;
+		
+		if( -1 == MarkerOld )
+			MarkerOld = ( Marker - 20 );
+		else	MarkerOld -= 20;
+
+		for (points = 0; begin < end; begin ++, points ++) { 
+			
+			if( begin < MarkerOld || begin > Marker +20 ) {
+				continue;
+			}
+			
+			CRAYON_BLANC
+			gdk_draw_line (VarSplit.AdrWidgetSpectre->window,
+					gc,
+					points,
+					VARSPLIT_SPECTRE_Y,
+					points,
+					VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H +1
+					);
+			
+			// MaxScale_0
+			if (begin >= SelBegin &&  begin <= SelEnd) {
+				CRAYON_BLEU		// LA SELECTION
+			} else {
+				CRAYON_NOIR		// LA NON SELECTION
+			}
+			gdk_draw_line (VarSplit.AdrWidgetSpectre->window,
+					gc,
+					points,
+					VarSplit.MaxScale_0 [ points ] . y,
+					points,
+					VarSplit.MinScale_0 [ points ] . y
+					);
+			
+			// MaxScale_1
+			if (begin >= SelBegin &&  begin <= SelEnd) {
+				CRAYON_BLEU_CLAIR	// LA SELECTION
+			} else {
+				CRAYON_GRIS		// LA NON SELECTION
+			}
+			gdk_draw_line (VarSplit.AdrWidgetSpectre->window,
+					gc,
+					points,
+					VarSplit.MaxScale_1 [ points ] . y,
+					points,
+					VarSplit.MinScale_1 [ points ] . y
+					);
+			
+			// MaxScale_2
+			if (begin >= SelBegin &&  begin <= SelEnd) {
+				CRAYON_BLEU_CLAIR_PLUS	// LA SELECTION
+			} else {
+				CRAYON_GRIS_CLAIR	// LA NON SELECTION
+			}
+			gdk_draw_line (VarSplit.AdrWidgetSpectre->window,
+					gc,
+					points,
+					VarSplit.MaxScale_2 [ points ] . y,
+					points,
+					VarSplit.MinScale_2 [ points ] . y
+					);
+		}
+				
+		// AFFICHE CURSEUR DEBUT
+		if (SelBegin >= save_begin && SelBegin < Len) {
+			CRAYON_ORANGE
+			gdk_draw_line (
+				VarSplit.AdrWidgetSpectre->window,
+				gc,
+				SelBegin  -save_begin,
+				VARSPLIT_SPECTRE_Y,
+				SelBegin - save_begin,
+				VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H
+				);
+		}
+		
+		// AFFICHE CURSEUR FIN
+		if (VarSplit.SelecteurActif == VarSplit.NbrSelecteurs -1) SelEnd --;
+		if (SelEnd >= save_begin && SelEnd < Len) {
+			CRAYON_VERT
+			gdk_draw_line (
+				VarSplit.AdrWidgetSpectre->window,
+				gc,
+				SelEnd - save_begin,
+				VARSPLIT_SPECTRE_Y,
+				SelEnd - save_begin,
+				VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H
+				);
+		}
+		
+		// AFFICHE LE CURSEUR AUDIO
+		if (VarSplit.PercentActivePlay >= 0.0) {
+			if (Marker >= save_begin && Marker < Len) {
+				CRAYON_ROUGE
+				gdk_draw_line (
+					VarSplit.AdrWidgetSpectre->window,
+					gc,
+					Marker - save_begin,
+					VARSPLIT_SPECTRE_Y,
+					Marker - save_begin,
+					VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H -2
+					);
+				gdk_draw_rectangle (
+					VarSplit.AdrWidgetSpectre->window,
+					gc,
+					TRUE,
+					Marker - save_begin -6,
+					VARSPLIT_SPECTRE_Y + VARSPLIT_SPECTRE_H -12,
+					14,
+					12
+					);
+			}
+		}
+		
+		// CLOSE DRAW
+		gdk_gc_destroy (gc);
+
+		MarkerOld = Marker;
+	}
 }
 
 
