@@ -303,11 +303,13 @@ STRUCT_TAGS_FILE_MP3 StructTagsFileMp3 [] = {
 { 45, "Meditative"},
 {142, "Merengue"},
 {  9, "Metal"},
+{148, "Misc"},
 { 77, "Musical"},
 { 82, "National Folk"},
 { 64, "Native American"},
 {133, "Negerpunk"},
 { 10, "New Age"},
+{ 10, "NewAge"},
 { 66, "New Wave"},
 { 39, "Noise"},
 { 11, "Oldies"},
@@ -370,16 +372,31 @@ STRUCT_TAGS_FILE_MP3 StructTagsFileMp3 [] = {
 };
 // 
 // 
-gint tags_get_genre_by_value (gchar *name)
+gint tags_get_genre_by_value( gchar *p_name )
 {
-	gint	 i;
-	for (i=0; StructTagsFileMp3[ i ].num != -1; i++) {
-		if( strlen( name ) == strlen( StructTagsFileMp3[ i ].name ) &&
-			0 == strcmp( name, StructTagsFileMp3[ i ].name ) )
-			return (StructTagsFileMp3[ i ].num);
-	}
+	gint	i;
+	gint	RetNum = -1;
+	gchar	*NameSrc = g_ascii_strdown( p_name, -1 );
+	gchar	*NameStruct = NULL;
+	
+	// g_print( "-- RECHERCHE DE: '%s'  '%s'\n", p_name, NameSrc );
+	for( i=0; StructTagsFileMp3[ i ].num != -1; i++ ) {
+
+		NameStruct = g_ascii_strdown( StructTagsFileMp3[ i ].name, -1 );
 		
-	return (-1);
+		
+		if( strlen( NameSrc ) == strlen( NameStruct ) && 0 == strcmp( NameSrc, NameStruct ) ) {
+			// g_print( "NameSrc = %s   NameStruct = %s\n", NameSrc, NameStruct );
+			RetNum = StructTagsFileMp3[ i ].num;
+			break;
+		}
+		g_free( NameStruct );	NameStruct = NULL;
+	}
+	
+	if( NULL != NameSrc )	 { g_free( NameSrc );		NameSrc = NULL;		}
+	if( NULL != NameStruct ) { g_free( NameStruct );	NameStruct = NULL;	}
+	
+	return( RetNum );
 }
 // 
 // 
@@ -411,15 +428,15 @@ gint tags_get_num_combobox (gint value)
 }
 // 
 // 
-gchar *tags_get_genre_by_name (gint value)
+gchar *tags_get_genre_by_name( gint value )
 {
 	gint i;
 
-	if (value < 0 || value > 148) return ((gchar *)NULL);
+	if( value < 0 || value > 148 ) return ((gchar *)NULL );
 
-	for (i=0; StructTagsFileMp3[ i ].num != value; i++);
+	for( i=0; StructTagsFileMp3[ i ].num != value; i++ );
 
-	return ((gchar *)StructTagsFileMp3[ i ].name);
+	return( (gchar *)StructTagsFileMp3[ i ].name );
 }
 // 
 // 
@@ -435,6 +452,7 @@ gchar *tags_get_str_type_file_is (TYPE_FILE_IS type)
 	else if (type == FILE_IS_OGG)      strcpy (str_type_file, "OGG ");
 	else if (type == FILE_IS_SHN)      strcpy (str_type_file, "SHN ");
 	else if (type == FILE_IS_M4A)      strcpy (str_type_file, "M4A ");
+	else if (type == FILE_IS_VID_M4A)  strcpy (str_type_file, "M4A ");
 	else if (type == FILE_IS_AAC)      strcpy (str_type_file, "AAC ");
 	else if (type == FILE_IS_WMA)      strcpy (str_type_file, "WMA ");
 	else if (type == FILE_IS_RM)       strcpy (str_type_file, "RM ");
