@@ -68,11 +68,11 @@ typedef struct {
 	FILE	*file;			// Handle du fichier si different de NULL
 } WAVE;
 
-/*
-*---------------------------------------------------------------------------
-* TAGS_WAV.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_WAV.C
+// ---------------------------------------------------------------------------
+// 
 INFO_WAV	*tagswav_remove_info( INFO_WAV *info );
 INFO_WAV	*tagswav_get_info( gchar *namefile );
 gboolean	tagswav_file_is_mono( gchar *namefile );
@@ -80,12 +80,11 @@ gboolean	tagswav_file_GetBitrate( gchar *namefile, gint *Channels, gint *Hertz,
 gint		tagswav_get_time_sec( gchar *namefile );
 gboolean	tagswav_read_file( gchar *wave_file, WAVE *son );
 void		tagswav_close_file( WAVE *son );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS.C
+// ---------------------------------------------------------------------------
+// 
 TAGS		*tags_alloc( gboolean bool_tag_cd );
 TAGS		*tags_remove( TAGS *tags );
 TAGS		*tags_set( gchar *filename, TAGS *tags );
@@ -93,124 +92,111 @@ void		tags_set_flag_modification( TAGS *tags, gboolean p_flag );
 gboolean	tags_is_modified( TAGS *tags );
 gchar		*tags_get_time_wav( gchar *namefile );
 gchar		*tags_get_time( gchar *namefile );
-gint		tags_get_genre_by_value( gchar *name );
+gint		tags_get_genre_by_value( gchar *p_name );
 gchar		*tags_get_str_type_file_is( TYPE_FILE_IS type );
 void		tags_set_elements_combobox( GtkWidget *widget );
 gint		tags_get_elements_combobox( gint num );
 gint		tags_get_num_combobox( gint value );
 gchar		*tags_get_genre_by_name( gint value );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_FLAC.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_FLAC.C
+// ---------------------------------------------------------------------------
+// 
 INFO_FLAC	*tagsflac_remove_info( INFO_FLAC *info );
 INFO_FLAC	*tagsflac_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_MP3.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_MP3.C
+// ---------------------------------------------------------------------------
+// 
 INFO_MP3	*tagsmp3_remove_info( INFO_MP3 *info );
 INFO_MP3	*tagsmp3_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_OGG.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_OGG.C
+// ---------------------------------------------------------------------------
+// 
 INFO_OGG	*tagsogg_remove_info( INFO_OGG *info );
 INFO_OGG	*tagsogg_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_M4A_.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_M4A_.C
+// ---------------------------------------------------------------------------
+// 
 INFO_M4A	*tagsm4a_remove_info( INFO_M4A *info );
 INFO_M4A	*tagsm4a_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_AAC_.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_AAC_.C
+// ---------------------------------------------------------------------------
+// 
 INFO_AAC	*tagsaac_remove_info( INFO_AAC *info );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_SHN.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_SHN.C
+// ---------------------------------------------------------------------------
+// 
 INFO_SHN	*tagsshn_remove_info( INFO_SHN *info );
 INFO_SHN	*tagsshn_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_WMA.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_WMA.C
+// ---------------------------------------------------------------------------
+// 
 INFO_WMA	*tagswma_remove_info( INFO_WMA *info );
 INFO_WMA	*tagswma_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_MPC.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_MPC.C
+// ---------------------------------------------------------------------------
+// 
 INFO_MPC	*tagsmpc_remove_info( INFO_MPC *info );
 INFO_MPC	*tagsmpc_get_info( DETAIL *detai );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_APE.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_APE.C
+// ---------------------------------------------------------------------------
+// 
 INFO_APE	*tagsape_remove_info( INFO_APE *info );
 INFO_APE	*tagsape_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_WAVPACK.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_WAVPACK.C
+// ---------------------------------------------------------------------------
+// 
 INFO_WAVPACK	*tagswavpack_remove_info( INFO_WAVPACK *info );
 INFO_WAVPACK	*tagswavpack_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_RM.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_RM.C
+// ---------------------------------------------------------------------------
+// 
 INFO_RM		*tagsrm_remove_info( INFO_RM *info );
 INFO_RM		*tagsrm_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_DTS.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_DTS.C
+// ---------------------------------------------------------------------------
+// 
 INFO_DTS	*tagsdts_remove_info( INFO_DTS *info );
 INFO_DTS	*tagsdts_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_AIFF.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_AIFF.C
+// ---------------------------------------------------------------------------
+// 
 INFO_AIFF	*tagsaiff_remove_info( INFO_AIFF *info );
 INFO_AIFF	*tagsaiff_get_info( DETAIL *detail );
-
-/*
-*---------------------------------------------------------------------------
-* TAGS_AC3.C
-*---------------------------------------------------------------------------
-*/
+// 
+// ---------------------------------------------------------------------------
+//  TAGS_AC3.C
+// ---------------------------------------------------------------------------
+// 
 INFO_AC3	*tagsac3_remove_info( INFO_AC3 *info );
 INFO_AC3	*tagsac3_get_info( DETAIL *detail );
 
+
 #endif
 
 
