@@ -113,14 +113,21 @@ INFO_APE *tagsape_get_info (DETAIL *detail)
 {
 	INFO_APE	*ptrinfo = NULL;
 	SHNTAG		*ShnTag = GetInfo_shntool (detail->namefile);
+	gint		m;
+	gint		s;
+	gint		sec;
 
 	ptrinfo = (INFO_APE *)g_malloc0 (sizeof (INFO_APE));
 	if (ptrinfo == NULL) return (NULL);
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
 	
-	ptrinfo->SecTime  = ShnTag->SecTime;
-	ptrinfo->time     = g_strdup (ShnTag->time);
 	ptrinfo->size     = g_strdup (ShnTag->size);
+	ptrinfo->SecTime =
+	sec = ShnTag->SecTime;
+	s = sec % 60; sec /= 60;
+	m = sec % 60; sec /= 60;
+	if (sec > 0) ptrinfo->time = g_strdup_printf ("%02d:%02d:%02d", sec, m, s);
+	else         ptrinfo->time = g_strdup_printf ("%02d:%02d", m, s);
 
 	/*
 	ptrinfo->tags = (TAGS *)tags_alloc (FALSE);
