@@ -83,12 +83,13 @@ INFO_FLAC *tagsflac_remove_info (INFO_FLAC *info)
 
 INFO_FLAC *tagsflac_get_info (DETAIL *detail)
 {
-	TagLib_File  *file;
-	TagLib_Tag   *tag;
-	INFO_FLAC    *ptrinfo = NULL;
+	TagLib_File	*file;
+	TagLib_Tag	*tag;
+	INFO_FLAC	*ptrinfo = NULL;
 	const TagLib_AudioProperties *properties;
-	gint          seconds;
-	gint          minutes;
+	gint		m;
+	gint		s;
+	gint		sec;
 
 	ptrinfo = (INFO_FLAC *)g_malloc0 (sizeof (INFO_FLAC));
 	if (ptrinfo == NULL) return (NULL);
@@ -110,22 +111,13 @@ INFO_FLAC *tagsflac_get_info (DETAIL *detail)
 		ptrinfo->tags->Number    = g_strdup_printf ("%d", ptrinfo->tags->IntNumber);
 		ptrinfo->tags->Genre     = g_strdup (taglib_tag_genre(tag));
 		ptrinfo->tags->IntGenre  = tags_get_genre_by_value (ptrinfo->tags->Genre);
-
-		ptrinfo->SecTime =  taglib_audioproperties_length(properties);
-
-		if (detail != NULL) {
-			// detail->ValuePlay.SecTime = ptrinfo->SecTime;
-		}
-
-		ptrinfo->ValueMark.SecTime    = taglib_audioproperties_length(properties);
-		// ptrinfo->ValueMark.ValueMarkA = 0.0;
-		// ptrinfo->ValueMark.ValueMarkB = 100.0;
-		// ptrinfo->ValueMark.Value = 0.0;
+		ptrinfo->SecTime         =  taglib_audioproperties_length(properties);
 		
-		seconds = taglib_audioproperties_length(properties) % 60;
-		minutes = (taglib_audioproperties_length(properties) - seconds) / 60;
-
-		ptrinfo->time     = g_strdup_printf ("%02d:%02d", minutes, seconds);
+		sec = taglib_audioproperties_length(properties);
+		s = sec % 60; sec /= 60;
+		m = sec % 60; sec /= 60;
+		if (sec > 0) ptrinfo->time = g_strdup_printf ("%02d:%02d:%02d", sec, m, s);
+		else         ptrinfo->time = g_strdup_printf ("%02d:%02d", m, s);
 
 		/*
 		printf("title   - \"%s\"\n", taglib_tag_title(tag));
