@@ -171,8 +171,9 @@ INFO_MP3 *tagsmp3_get_info (DETAIL *detail)
 	TagLib_File  *file;
 	TagLib_Tag   *tag;
 	const TagLib_AudioProperties *properties;
-	gint          seconds;
-	gint          minutes;
+	gint		m;
+	gint		s;
+	gint		sec;
 	
 	/* PRINT_FUNC_LF();*/
 	
@@ -210,21 +211,14 @@ INFO_MP3 *tagsmp3_get_info (DETAIL *detail)
 		
 		
 		ptrinfo->tags->IntGenre  = tags_get_genre_by_value (ptrinfo->tags->Genre);
-
-		seconds = taglib_audioproperties_length(properties) % 60;
-		minutes = (taglib_audioproperties_length(properties) - seconds) / 60;
-		ptrinfo->SecTime =  taglib_audioproperties_length(properties);
-
-		if (detail != NULL) {
-			// detail->ValuePlay.SecTime = ptrinfo->SecTime;
-		}
-
-		ptrinfo->ValueMark.SecTime    = taglib_audioproperties_length(properties);
-		// ptrinfo->ValueMark.ValueMarkA = 0.0;
-		// ptrinfo->ValueMark.ValueMarkB = 100.0;
-		// ptrinfo->ValueMark.Value = 0.0;
-
-		ptrinfo->time     = g_strdup_printf ("%02d:%02d", minutes, seconds);
+		
+		ptrinfo->SecTime =
+		sec = taglib_audioproperties_length(properties);
+		s = sec % 60; sec /= 60;
+		m = sec % 60; sec /= 60;
+		if (sec > 0) ptrinfo->time = g_strdup_printf ("%02d:%02d:%02d", sec, m, s);
+		else         ptrinfo->time = g_strdup_printf ("%02d:%02d", m, s);
+		
 		ptrinfo->bitrate  = g_strdup_printf ("%d", taglib_audioproperties_bitrate(properties));
 		ptrinfo->mpeg_is  = tagsmp3_type_mpeg (detail->namefile);
 		ptrinfo->size     = g_strdup_printf ("%d Ko", (gint)libutils_get_size_file (detail->namefile) / 1024);
