@@ -91,10 +91,11 @@ gboolean tagswav_read_file (gchar *wave_file, WAVE *son)
 	gint		tt_read = 0;
 	gint		cpt;
 	gboolean	BoolFound = FALSE;
-	gchar		Str [ 10 ];
+	// gchar		Str [ 10 ];
+	
+	// PRINT_FUNC_LF();
+	// g_print("\t%s\n", wave_file);
 	
-	PRINT_FUNC_LF();
-	g_print("\t%s\n", wave_file);
 	// INIT STRUCTURE
 	tagswav_init (son);
 	
@@ -155,47 +156,46 @@ gboolean tagswav_read_file (gchar *wave_file, WAVE *son)
 		n_read = fread(&son->DATA.Subchunk2ID, 4, 1, son->file);
 		n_read = fread(&son->DATA.Subchunk2Size, 4, 1, son->file);
 	
-		g_print ("\tBoolFound DATA = %s\n", BoolFound ? "TRUE" : "FALSE");
+		// g_print ("\tBoolFound DATA = %s\n", BoolFound ? "TRUE" : "FALSE");
 			
-		Str [ 0 ] = son->RIFF.ChunkID [ 0 ];
-		Str [ 1 ] = son->RIFF.ChunkID [ 1 ];
-		Str [ 2 ] = son->RIFF.ChunkID [ 2 ];
-		Str [ 3 ] = son->RIFF.ChunkID [ 3 ];
-		Str [ 4 ] = '\0';
-		g_print ("\tChunkID        = %s\n", Str);
-		g_print ("\tChunkSize      = %d\n", son->RIFF.ChunkSize);
+		// Str [ 0 ] = son->RIFF.ChunkID [ 0 ];
+		// Str [ 1 ] = son->RIFF.ChunkID [ 1 ];
+		// Str [ 2 ] = son->RIFF.ChunkID [ 2 ];
+		// Str [ 3 ] = son->RIFF.ChunkID [ 3 ];
+		// Str [ 4 ] = '\0';
+		// g_print ("\tChunkID        = %s\n", Str);
+		// g_print ("\tChunkSize      = %d\n", son->RIFF.ChunkSize);
 		
-		Str [ 0 ] = son->RIFF.Format [ 0 ];
-		Str [ 1 ] = son->RIFF.Format [ 1 ];
-		Str [ 2 ] = son->RIFF.Format [ 2 ];
-		Str [ 3 ] = son->RIFF.Format [ 3 ];
-		Str [ 4 ] = '\0';
-		g_print ("\tFormat         = %s\n", Str);
+		// Str [ 0 ] = son->RIFF.Format [ 0 ];
+		// Str [ 1 ] = son->RIFF.Format [ 1 ];
+		// Str [ 2 ] = son->RIFF.Format [ 2 ];
+		// Str [ 3 ] = son->RIFF.Format [ 3 ];
+		// Str [ 4 ] = '\0';
+		// g_print ("\tFormat         = %s\n", Str);
 		
-		Str [ 0 ] = son->FMT.Subchunk1ID [ 0 ];
-		Str [ 1 ] = son->FMT.Subchunk1ID [ 1 ];
-		Str [ 2 ] = son->FMT.Subchunk1ID [ 2 ];
-		Str [ 3 ] = son->FMT.Subchunk1ID [ 3 ];
-		Str [ 4 ] = '\0';
-		g_print ("\tSubchunk1ID    = %s\n", Str);
+		// Str [ 0 ] = son->FMT.Subchunk1ID [ 0 ];
+		// Str [ 1 ] = son->FMT.Subchunk1ID [ 1 ];
+		// Str [ 2 ] = son->FMT.Subchunk1ID [ 2 ];
+		// Str [ 3 ] = son->FMT.Subchunk1ID [ 3 ];
+		// Str [ 4 ] = '\0';
+		// g_print ("\tSubchunk1ID    = %s\n", Str);
+		// g_print ("\tSubchunk1Size  = %d\n", son->FMT.Subchunk1Size);  
+		// g_print ("\tAudioFormat    = %d\n", son->FMT.AudioFormat);  
+		// g_print ("\tNumChannels    = %d\n", son->FMT.NumChannels);  
+		// g_print ("\tSampleRate     = %d\n", son->FMT.SampleRate);  
+		// g_print ("\tByteRate       = %d\n", son->FMT.ByteRate);  
+		// g_print ("\tBlockalign     = %d\n", son->FMT.Blockalign);  
+		// g_print ("\tBitsPerSample  = %d\n", son->FMT.BitsPerSample);
 		
-		g_print ("\tSubchunk1Size  = %d\n", son->FMT.Subchunk1Size);  
-		g_print ("\tAudioFormat    = %d\n", son->FMT.AudioFormat);  
-		g_print ("\tNumChannels    = %d\n", son->FMT.NumChannels);  
-		g_print ("\tSampleRate     = %d\n", son->FMT.SampleRate);  
-		g_print ("\tByteRate       = %d\n", son->FMT.ByteRate);  
-		g_print ("\tBlockalign     = %d\n", son->FMT.Blockalign);  
-		g_print ("\tBitsPerSample  = %d\n", son->FMT.BitsPerSample);
+		// Str [ 0 ] = son->DATA.Subchunk2ID [ 0 ];
+		// Str [ 1 ] = son->DATA.Subchunk2ID [ 1 ];
+		// Str [ 2 ] = son->DATA.Subchunk2ID [ 2 ];
+		// Str [ 3 ] = son->DATA.Subchunk2ID [ 3 ];
+		// Str [ 4 ] = '\0';
 		
-		Str [ 0 ] = son->DATA.Subchunk2ID [ 0 ];
-		Str [ 1 ] = son->DATA.Subchunk2ID [ 1 ];
-		Str [ 2 ] = son->DATA.Subchunk2ID [ 2 ];
-		Str [ 3 ] = son->DATA.Subchunk2ID [ 3 ];
-		Str [ 4 ] = '\0';
-		g_print ("\tSubchunk2ID    = %s\n", Str);  
-		
-		g_print ("\tSubchunk2Size  = %d\n", son->DATA.Subchunk2Size);
-		g_print ("\n");
+		// g_print ("\tSubchunk2ID    = %s\n", Str);  
+		// g_print ("\tSubchunk2Size  = %d\n", son->DATA.Subchunk2Size);
+		// g_print ("\n");
  	}
 	else if (FALSE == BoolFound)  {
 		// fermeture du fichier  
@@ -297,7 +297,6 @@ INFO_WAV *tagswav_get_info (gchar *namefile)
 	// calcul de la duree
 	sec = son.DATA.Subchunk2Size / son.FMT.ByteRate;
 	ptrinfo->SecTime              = sec;
-	ptrinfo->ValueMark.SecTime    = sec;
 
 	s = sec % 60; sec /= 60;
 	m = sec % 60; sec /= 60;
