@@ -97,6 +97,8 @@ TRANS trans[] = {
 { _("definit le serveur a contacter pour les recherches titre") },
 { _("Parametres par defaut") },
 { _("<b> Serveur </b>") },
+{ _("Choix parmis les differentes bases de donnees pour le CD.") },
+{ _("<b>DiscId</b>") },
 { _("Extraire") },
 { _(" CD ") },
 { _("<b> Importer </b>") },
@@ -154,6 +156,7 @@ TRANS trans[] = {
 { _("Choix d'une nouvelle police.") },
 { _("Texte gras.") },
 { _("Texte italique.") },
+{ _("Apres une lecture de CD et un ajout d'etiquette, ce menu permet la mise en forme des titres, auteurs ...") },
 { _("Ajouter du texte editable.") },
 { _("<b>Texte</b>") },
 { _("Saisissez ici un critere de recherche d'images.") },
