@@ -53,7 +53,7 @@
 #include "extra.h"
 #include "configuser.h"
 #include "web.h"
-#include "cd_cddb.h"
+#include "cd_curl.h"
 
 
 
@@ -154,7 +154,7 @@ void web_goto_url (gchar *str_web)
 		return;
 	}
 
-	if (CdCddb_test_access_web () == FALSE) {
+	if (CdCurl_test_access_web () == FALSE) {
 		
 		wininfo_create (
 			_("La liaison internet est absente"),
