@@ -193,6 +193,23 @@ typedef struct {
 
 VAR_WININFO	VarWinInfo = { NULL, FALSE };
 
+
+// QUITTER
+// 
+gboolean on_wind_info_destroy_event( GtkWidget *widget, GdkEvent *event, gpointer user_data )
+{
+	VarWinInfo.IsShow = FALSE;
+	gtk_widget_hide (VarWinInfo.AdrWin);
+	return TRUE;
+}
+// QUITTER
+// 
+gboolean on_wind_info_delete_event( GtkWidget *widget, GdkEvent *event, gpointer user_data )
+{
+	VarWinInfo.IsShow = FALSE;
+	gtk_widget_hide (VarWinInfo.AdrWin);
+	return TRUE;
+}
 // QUITTER
 // 
 void on_button_quitter_wininfo_clicked (GtkButton *button, gpointer user_data)
@@ -221,7 +238,7 @@ void wininfo_create (gchar *title, ...)
 		gtk_window_set_modal (GTK_WINDOW (VarWinInfo.AdrWin), TRUE);
 		libutils_set_default_icone_to_win (VarWinInfo.AdrWin);
 		
-		StrTitle = g_strdup_printf ("\n          <span font_desc=\"Courier bold 14\"><b>%s</b></span>          \n", title);
+		StrTitle = g_strdup_printf ("\n              <span font_desc=\"Courier bold 14\"><b>%s</b></span>              \n", title);
 		gtk_label_set_markup (GTK_LABEL (GLADE_GET_OBJECT("label_titre_wininfo")), StrTitle);
 		g_free (StrTitle);	StrTitle = NULL;
 	
