@@ -44,6 +44,7 @@
 
 #include "global.h"
 #include "conv.h"
+#include "win_vte.h"
 #include "win_scan.h"
 
 
@@ -165,7 +166,7 @@ gboolean WindScan_open (gchar *title, TYPE_PROGRESS TypeProgress)
 		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (VarWindScan.AdrProgressBar), 0.0);
 		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (VarWindScan.AdrProgressBar), _("Waiting ..."));
 	}
-	
+	WindScan_show_cancel( TRUE );
 	VarWindScan.HandlerTimeout = gtk_timeout_add (100, WindScan_timeout, 0);
 	
 	return (BoolIsShow);
@@ -228,7 +229,15 @@ void WindScan_show_expander (void)
 	gtk_widget_show (GTK_WIDGET (GLADE_GET_OBJECT("expander_windscan")));
 	gtk_expander_set_expanded (GTK_EXPANDER (GLADE_GET_OBJECT("expander_windscan")), TRUE);
 }
-
-
-
-
+// 
+// 
+void WindScan_show_cancel( gboolean p_bool_show )
+{
+	gtk_widget_set_sensitive( GTK_WIDGET( GLADE_GET_OBJECT( "button_cancel_windscan" )), p_bool_show );
+}
+// 
+// 
+void on_scrolledwindow_windscan_realize( GtkWidget *widget, gpointer user_data )
+{
+	WinVte_realize( widget );
+}
